/* A lexical scanner generated by flex */

/* Scanner skeleton version:
 * $Header: /home/daffy/u0/vern/flex/RCS/flex.skl,v 2.85 95/04/24 10:48:47 vern Exp $
 */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5

#include <stdio.h>


/* cfront 1.2 defines "c_plusplus" instead of "__cplusplus" */
#ifdef c_plusplus
#ifndef __cplusplus
#define __cplusplus
#endif
#endif


#ifdef __cplusplus

#include <stdlib.h>
#include <unistd.h>

/* Use prototypes in function declarations. */
#define YY_USE_PROTOS

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_PROTOS
#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef __TURBOC__
 #pragma warn -rch
 #pragma warn -use
#include <io.h>
#include <stdlib.h>
#define YY_USE_CONST
#define YY_USE_PROTOS
#endif

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif


#ifdef YY_USE_PROTOS
#define YY_PROTO(proto) proto
#else
#define YY_PROTO(proto) ()
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#define YY_BUF_SIZE 16384

typedef struct yy_buffer_state *YY_BUFFER_STATE;

extern int yyleng;
extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

/* The funky do-while in the following #define is used to turn the definition
 * int a single C statement (which needs a semi-colon terminator).  This
 * avoids problems with code like:
 *
 * 	if ( condition_holds )
 *		yyless( 5 );
 *	else
 *		do_something_else();
 *
 * Prior to using the do-while the compiler would get upset at the
 * "else" because it interpreted the "if" statement as being all
 * done when it reached the ';' after the yyless() call.
 */

/* Return all but the first 'n' matched characters back to the input stream. */

#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
		*yy_cp = yy_hold_char; \
		yy_c_buf_p = yy_cp = yy_bp + n - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yytext_ptr )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */
typedef unsigned int yy_size_t;


struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;
#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2
	};

static YY_BUFFER_STATE yy_current_buffer = 0;

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 */
#define YY_CURRENT_BUFFER yy_current_buffer


/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;

static int yy_n_chars;		/* number of characters read into yy_ch_buf */


int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 1;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart YY_PROTO(( FILE *input_file ));

void yy_switch_to_buffer YY_PROTO(( YY_BUFFER_STATE new_buffer ));
void yy_load_buffer_state YY_PROTO(( void ));
YY_BUFFER_STATE yy_create_buffer YY_PROTO(( FILE *file, int size ));
void yy_delete_buffer YY_PROTO(( YY_BUFFER_STATE b ));
void yy_init_buffer YY_PROTO(( YY_BUFFER_STATE b, FILE *file ));
void yy_flush_buffer YY_PROTO(( YY_BUFFER_STATE b ));
#define YY_FLUSH_BUFFER yy_flush_buffer( yy_current_buffer )

YY_BUFFER_STATE yy_scan_buffer YY_PROTO(( char *base, yy_size_t size ));
YY_BUFFER_STATE yy_scan_string YY_PROTO(( yyconst char *str ));
YY_BUFFER_STATE yy_scan_bytes YY_PROTO(( yyconst char *bytes, int len ));

static void *yy_flex_alloc YY_PROTO(( yy_size_t ));
static void *yy_flex_realloc YY_PROTO(( void *, yy_size_t ));
static void yy_flex_free YY_PROTO(( void * ));

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! yy_current_buffer ) \
		yy_current_buffer = yy_create_buffer( yyin, YY_BUF_SIZE ); \
	yy_current_buffer->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! yy_current_buffer ) \
		yy_current_buffer = yy_create_buffer( yyin, YY_BUF_SIZE ); \
	yy_current_buffer->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (yy_current_buffer->yy_at_bol)


#define YY_USES_REJECT
typedef unsigned char YY_CHAR;
FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;
typedef int yy_state_type;
extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state YY_PROTO(( void ));
static yy_state_type yy_try_NUL_trans YY_PROTO(( yy_state_type current_state ));
static int yy_get_next_buffer YY_PROTO(( void ));
static void yy_fatal_error YY_PROTO(( yyconst char msg[] ));

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 279
#define YY_END_OF_BUFFER 280
static yyconst short int yy_acclist[712] =
    {   0,
      280,  279,  279,    4,  279,    3,  279,  279,  279,  279,
       83,  279,   83,  279,    3,   83,  279,   83,  279,   83,
      279,   65,   83,  279,   83,  279,    8,   83,  279,   51,
       83,  279,   33,   83,  279,   45,   83,  279,   22,   83,
      279,   30,   83,  279,    6,   83,  279,   12,   83,  279,
       35,   83,  279,   28,   83,  279,   57,   83,  279,    5,
       83,  279,   83,  279,   26,   83,  279,   49,   83,  279,
       70,   83,  279,   43,   83,  279,   14,   83,  279,   83,
      279,   83,  279,    7,   83,  279,   50,   83,  279,   32,
       83,  279,   44,   83,  279,   21,   83,  279,   72,   83,

      279,   29,   83,  279,   63,   83,  279,   11,   83,  279,
       34,   83,  279,   27,   83,  279,   56,   83,  279,   52,
       83,  279,   46,   83,  279,   25,   83,  279,   48,   83,
      279,   67,   83,  279,   54,   83,  279,   62,   83,  279,
       42,   83,  279,   13,   83,  279,   59,   83,  279,   82,
       83,  279,   53,   83,  279,   74,   83,  279,   83,  279,
       83,  279,  245,  279,  245,  279,    3,  245,  279,  245,
      279,  227,  245,  279,  167,  245,  279,  212,  245,  279,
      194,  245,  279,  206,  245,  279,  182,  245,  279,  234,
      245,  279,  191,  245,  279,  225,  245,  279,  171,  245,

      279,  196,  245,  279,  189,  245,  279,  218,  245,  279,
      214,  245,  279,  208,  245,  279,  187,  245,  279,  210,
      245,  279,  229,  245,  279,  216,  245,  279,  224,  245,
      279,  204,  245,  279,  173,  245,  279,  221,  245,  279,
      244,  245,  279,  215,  245,  279,  245,  279,  167,  245,
      279,  212,  245,  279,  194,  245,  279,  206,  245,  279,
      191,  245,  279,  196,  245,  279,  189,  245,  279,  187,
      245,  279,  210,  245,  279,  204,  245,  279,  236,  245,
      279,  245,  279,  164,  279,  164,  279,    3,  164,  279,
      163,  164,  279,  164,  279,  142,  164,  279,  164,  279,

      129,  164,  279,  164,  279,  119,  164,  279,  109,  164,
      279,   85,  164,  279,  114,  164,  279,  107,  164,  279,
      134,  164,  279,  120,  164,  279,  127,  164,  279,  147,
      164,  279,  164,  279,  117,  164,  279,  164,  279,  162,
      164,  279,   86,  164,  279,  128,  164,  279,  164,  279,
      118,  164,  279,   99,  164,  279,  149,  164,  279,  108,
      164,  279,  140,  164,  279,   90,  164,  279,  113,  164,
      279,  106,  164,  279,  133,  164,  279,  130,  164,  279,
      125,  164,  279,  103,  164,  279,  126,  164,  279,  144,
      164,  279,  132,  164,  279,  139,  164,  279,  116,  164,

      279,   92,  164,  279,  136,  164,  279,  161,  164,  279,
      131,  164,  279,  151,  164,  279,  164,  279,    2,    3,
        2,   10,    9,   19,   58,   31,   47,   23,   55,   60,
       73,    9,   40,   68,   18,   16,   38,   64,   39,   69,
        6,   17,    5,   41,   66,   15,   61,   37,   80,   77,
       79,   76,   81,   71,   20,   24,    8,   22,   26,   51,
       33,   45,   30,   12,   35,   28,   49,   43,   14,   75,
       36,  183,  188,  213,  195,  207,  192,  197,  190,  211,
      205,    3,    3,    3,    3,  237,   98,  135,  102,  150,
      145,   97,  141,  146,   96,  143,  112,  124,   84,  154,

      158,   94,  148,  138,  122,   88,  101,  105,   87,  111,
      123,  100,  159,   91,  115,  104,  137,  121,   93,  152,
      278,  247,  278,  248,  278,  277,  278,  277,  276,  278,
      276,  278,  276,  278,  276,  278,  276,  278,  276,  278,
      276,  278,  278,  246,    2,    2,   78,    3,    3,  110,
      157,  155,  153,   95,   89,    2,    2,    3,    3,  156,
        2,    2,  169,  220,  209,  217,  235,  222,  193,  168,
      181,  172,  186,  174,  231,  219,  232,  232,    3,  226,
      201,  166,  177,  165,  203,  175,  223,  199,  201,  199,
        3,  179,  184,  180,  185,  198,  160,  275,  270,  268,

      256,  270,  268,    2,    2,  228,  230,  233,    3,  202,
      200,    3,  242,  239,  241,  238,  243,    2,    3,    3,
        2,    3,  269,  266,  267,  255,  254,  252,  272,  269,
      272,  267,  272,  264,    2,    3,    2,    1,  240,    2,
        1,  265,  253,  250,  251,  271,  263,  262,  260,  274,
        2,    1,    2,    1,    2,    1,  249,  261,  258,  259,
        2,    1,  170,    2,    1,  178,  176,    2,    1,  257,
      273,    2,    1,    2,    1,    2,    1,    2,    1,    2,
        1,    2,    1,    2,    1,    2,    1,    2,    1,    2,
        1,    2,    1,    2,    1,    2,    1,    2,    1,    2,

        1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1
    } ;

static yyconst short int yy_accept[719] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        3,    4,    6,    8,    9,   10,   11,   13,   15,   18,
       20,   22,   25,   27,   30,   33,   36,   39,   42,   45,
       48,   51,   54,   57,   60,   63,   65,   68,   71,   74,
       77,   80,   82,   84,   87,   90,   93,   96,   99,  102,
      105,  108,  111,  114,  117,  120,  123,  126,  129,  132,
      135,  138,  141,  144,  147,  150,  153,  156,  159,  161,
      163,  165,  167,  170,  172,  175,  178,  181,  184,  187,
      190,  193,  196,  199,  202,  205,  208,  211,  214,  217,
      220,  223,  226,  229,  232,  235,  238,  241,  244,  247,

      249,  252,  255,  258,  261,  264,  267,  270,  273,  276,
      279,  282,  284,  286,  288,  291,  294,  296,  299,  301,
      304,  306,  309,  312,  315,  318,  321,  324,  327,  330,
      333,  335,  338,  340,  343,  346,  349,  351,  354,  357,
      360,  363,  366,  369,  372,  375,  378,  381,  384,  387,
      390,  393,  396,  399,  402,  405,  408,  411,  414,  417,
      419,  419,  419,  420,  421,  422,  423,  424,  425,  426,
      428,  429,  430,  431,  432,  433,  434,  435,  436,  437,
      438,  439,  440,  441,  442,  442,  443,  444,  445,  446,
      447,  448,  449,  449,  450,  451,  452,  453,  454,  455,

      456,  457,  458,  459,  460,  461,  462,  463,  464,  465,
      466,  467,  468,  469,  470,  471,  472,  473,  474,  475,
      476,  477,  478,  479,  480,  480,  481,  482,  482,  482,
      482,  482,  483,  484,  485,  486,  486,  486,  487,  487,
      488,  489,  489,  489,  490,  491,  492,  493,  494,  495,
      495,  496,  497,  498,  499,  500,  501,  502,  503,  504,
      505,  506,  507,  508,  509,  510,  511,  512,  513,  514,
      515,  516,  517,  518,  519,  520,  521,  522,  524,  526,
      528,  529,  531,  533,  535,  537,  539,  541,  543,  544,
      545,  546,  547,  548,  548,  548,  548,  548,  548,  548,

      549,  549,  550,  550,  550,  550,  550,  551,  552,  552,
      553,  554,  555,  556,  556,  556,  556,  556,  556,  556,
      556,  556,  557,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  559,  559,
      559,  559,  559,  559,  559,  559,  559,  559,  559,  559,
      559,  559,  559,  559,  559,  559,  559,  560,  560,  560,
      560,  560,  560,  560,  560,  560,  560,  560,  560,  560,
      560,  560,  560,  560,  561,  561,  561,  561,  561,  561,

      561,  561,  561,  562,  563,  563,  563,  564,  565,  566,
      567,  568,  569,  570,  571,  572,  573,  574,  575,  575,
      576,  576,  577,  578,  578,  579,  580,  581,  582,  583,
      584,  585,  586,  587,  588,  589,  590,  591,  592,  593,
      593,  593,  594,  594,  594,  595,  596,  597,  597,  598,
      599,  600,  601,  602,  602,  602,  602,  602,  602,  602,
      603,  604,  604,  604,  604,  604,  604,  604,  605,  606,
      607,  608,  609,  610,  611,  612,  613,  614,  615,  616,
      617,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,

      618,  619,  619,  620,  621,  621,  621,  621,  621,  621,
      621,  621,  621,  621,  621,  621,  621,  621,  621,  621,
      621,  621,  621,  621,  622,  622,  622,  623,  623,  623,
      624,  625,  626,  627,  628,  629,  630,  630,  632,  634,
      635,  635,  635,  636,  636,  636,  636,  637,  637,  637,
      637,  637,  637,  637,  637,  637,  637,  637,  638,  638,
      639,  639,  639,  640,  640,  640,  640,  640,  640,  640,
      640,  641,  641,  642,  642,  642,  642,  643,  644,  645,
      646,  647,  648,  649,  650,  651,  651,  651,  651,  651,
      651,  652,  652,  653,  653,  653,  653,  653,  653,  653,

      653,  653,  653,  653,  653,  653,  654,  654,  655,  655,
      655,  655,  655,  655,  655,  655,  655,  655,  655,  656,
      656,  657,  657,  657,  657,  657,  658,  659,  660,  661,
      661,  662,  662,  663,  663,  663,  664,  664,  664,  664,
      664,  664,  664,  665,  665,  666,  667,  668,  668,  668,
      669,  669,  670,  671,  672,  673,  673,  674,  675,  675,
      676,  677,  677,  678,  679,  679,  680,  681,  681,  682,
      683,  683,  684,  685,  685,  686,  687,  687,  688,  689,
      689,  690,  691,  691,  692,  693,  693,  694,  695,  695,
      696,  697,  697,  698,  699,  699,  700,  701,  701,  702,

      703,  703,  704,  704,  705,  705,  706,  706,  707,  707,
      708,  708,  709,  709,  710,  711,  712,  712
    } ;

static yyconst int yy_ec[256] =
    {   0,
        1,    2,    3,    4,    5,    5,    5,    5,    6,    7,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    8,    8,    8,    8,    8,    8,    9,
       10,   11,   10,   12,   13,   10,   14,   15,   16,   10,
       10,   10,   10,   10,   17,   18,   19,   20,   21,   10,
       10,   10,   10,   10,   10,   22,   23,   10,   10,   10,
       24,   10,   25,   10,   26,   27,   28,   29,   30,   31,
       32,   33,   34,   35,   36,   37,   38,   39,   40,   41,
       42,   43,   44,   45,   46,   47,   48,   49,   50,   48,
       51,   52,   53,   54,   55,    8,   56,   57,   58,   59,

       60,   61,   62,   63,   64,   65,   66,   67,   68,   69,
       70,   71,   72,   73,   74,   75,   76,   77,   78,   79,
       80,   81,   82,   83,   84,   85,    8,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,

       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   87
    } ;

static yyconst int yy_meta[88] =
    {   0,
        1,    1,    1,    2,    2,    3,    4,    1,    5,    5,
        6,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    7,    8,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        8,    8,    7,    8,    8,    8,    7,    7,    7,    7,
        5,    1,    1,    1,    9,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,    1,    1,    1,    1,   11,   11
    } ;

static yyconst short int yy_base[820] =
    {   0,
        0,    1,   53, 1735,  140, 1734,  227, 1733, 1745,  309,
     1749, 1749, 1749,    0,    0, 1718,  310, 1749, 1749,  291,
        0, 1749,  372, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
     1749, 1749, 1749, 1749, 1749,  310, 1749, 1749, 1680, 1749,
     1749,    0,  259,  262, 1679, 1678, 1677, 1749, 1749, 1676,
     1749, 1674, 1674, 1673, 1749, 1749, 1749, 1749, 1672, 1749,
     1749, 1749, 1671, 1657, 1749, 1749, 1749, 1649, 1662, 1704,
      315, 1749, 1749,    0, 1749,  286,  289,  290,  291, 1749,
     1749,  292, 1749, 1749,  294,  300, 1749, 1749, 1749, 1677,
      303, 1749, 1749, 1749,  307, 1749, 1749, 1749, 1749,  367,

      266, 1665, 1664, 1663, 1662, 1661, 1660, 1670, 1658, 1657,
     1636, 1692,  325, 1749, 1749,  320,    0, 1749,  337, 1749,
     1684, 1683, 1749, 1749, 1749, 1749, 1749,  360, 1749,  293,
     1682, 1681,    0, 1749,  373, 1749, 1650, 1649, 1626, 1749,
     1641, 1749, 1624, 1749, 1639, 1749, 1749, 1749, 1622, 1749,
     1749, 1749, 1643, 1637, 1613, 1749, 1749, 1749, 1614, 1663,
      457,    0,    0,    0, 1650, 1749, 1630, 1749, 1749, 1749,
     1749, 1749, 1749, 1749, 1652, 1749, 1749, 1749, 1749, 1749,
     1749, 1613, 1749, 1749, 1612, 1749, 1749, 1749, 1749, 1749,
     1749, 1602, 1597, 1749, 1749, 1749, 1749, 1749, 1749, 1749,

     1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
     1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
     1749, 1749, 1749, 1749, 1595, 1749, 1749, 1571, 1561, 1552,
     1550, 1549,  312,  266, 1539, 1530, 1551, 1749, 1577, 1749,
     1749, 1542,  282, 1749, 1749, 1749, 1749, 1749, 1749, 1527,
     1749, 1749, 1749, 1749, 1749, 1749, 1749, 1503, 1749, 1749,
     1749, 1502, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
     1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749,
     1749, 1576, 1567, 1565, 1564, 1554, 1545, 1543, 1542, 1749,
        0, 1499, 1749, 1446,  459,  337,  345,  484,  454, 1471,

      535, 1460,  507,  459,  347, 1435, 1749, 1749, 1457, 1443,
     1749, 1749, 1749, 1495, 1494, 1486, 1484, 1483, 1473, 1468,
     1467,    0, 1439,  368, 1379, 1378, 1368, 1363, 1362, 1354,
     1352, 1351, 1341, 1336, 1335, 1327, 1325, 1324, 1314, 1309,
     1308, 1300, 1298, 1317, 1287, 1282, 1281, 1273, 1271, 1270,
     1260, 1255, 1254, 1246, 1244, 1243, 1233, 1237, 1227, 1219,
     1217, 1216, 1206, 1201, 1200, 1192, 1190, 1189, 1179, 1174,
     1173, 1165, 1163, 1162, 1152, 1147, 1170, 1138, 1136, 1135,
     1125, 1120, 1119, 1111, 1109, 1108, 1098, 1093, 1092, 1084,
     1082, 1097, 1092, 1749,   11,   15,   23,  577,   19,  607,

      614,  625,    0, 1106, 1065, 1057, 1749, 1749, 1749, 1749,
     1749, 1749, 1749, 1749, 1749, 1749, 1749, 1749, 1055, 1749,
      387, 1749,  388, 1075, 1065, 1053, 1749,  390, 1749, 1749,
     1749, 1749, 1749, 1749,  421, 1059, 1051, 1039, 1749,  430,
      621, 1749, 1054,  491, 1749, 1749, 1749, 1017, 1749, 1749,
     1095, 1094, 1086, 1084, 1083, 1073, 1068, 1067, 1059, 1057,
     1056, 1046, 1041, 1040, 1032, 1030, 1029,    0,   38, 1749,
     1749, 1749,  949, 1749, 1749,  948, 1749, 1749, 1749, 1749,
     1749,  955,  947,  998,  997,  987,  982,  981,  973,  971,
      970,  960,  955,  954,  946,  944,  943,  933,  928,  927,

        0,  371,  872,  848,  825,  824,  488,  583,  653,  509,
      892,  330,  401,   27,  551,  658,  662,   23,  875,  872,
      862,  539,  820,    0,  511,  818,  800,  472,  806, 1749,
      863, 1749, 1749,  859,  858, 1749,  848, 1749, 1749,  847,
      843,  842,    0,  586,  590,  815,  756,  744,  728,  724,
      801,  785,  783,  727,  725,  705,  697,    0,  611,    0,
      599,  499, 1749,  683,  687,  691,  674,  695,  670,  695,
        0,  632,    0,  619,  530,  598, 1749, 1749,  654, 1749,
     1749, 1749,  653,  650, 1749,  640,  631,  623,  615,  606,
        0,  634,    0,  444,  522,  502,  482,  556,  546,  545,

      536,  535,  532,  519,  517,    0,  641,    0,  659,  477,
      701,  715,  719,  405,  449,  437,  424,  709,    0,  666,
        0,  559,  380,  379,  693, 1749, 1749,  421, 1749,  412,
        0,  726,    0,  357,  342, 1749,  325,  296,  292,  290,
        3,    0,    0,  728,    0, 1749, 1749,  738,    0,    0,
      729,    0, 1749, 1749,    0,  740,    0,    0,  741,    0,
        0,  742,    0,    0,  743,    0,    0,  744,    0,    0,
      750,    0,    0,  751,    0,    0,  752,    0,    0,  753,
        0,    0,  759,    0,    0,  761,    0,    0,  762,    0,
        0,  763,    0,    0,  765,    0,    0,  769,    0, 1749,

      771,    0,  772,    0,  773,    0,  775,    0,  779,    0,
      781,    0,  782,    0,    0, 1749, 1749,  793,  798,  803,
      813,  824,  829,  834,  839,  849,  850,  855,  860,  871,
      878,  881,  892,  897,  908,  919,  924,  935,  946,  951,
      962,  973,  978,  989, 1000, 1005, 1016, 1027, 1032, 1043,
     1054, 1059, 1070, 1081, 1086, 1097, 1108, 1113, 1124, 1135,
     1140, 1151, 1162, 1167, 1178, 1189, 1194, 1205, 1216, 1221,
     1232, 1243, 1248, 1259, 1270, 1275, 1286, 1297, 1302, 1313,
     1324, 1329, 1340, 1351, 1356, 1367, 1378, 1383, 1394, 1405,
     1410, 1421, 1432, 1437, 1448, 1459, 1464, 1475, 1486, 1491,

     1502, 1513, 1518, 1529, 1540, 1551, 1562, 1573, 1584, 1595,
     1606, 1617, 1628, 1639, 1650, 1661, 1672, 1683, 1694
    } ;

static yyconst short int yy_def[820] =
    {   0,
      718,  718,  717,    3,  717,    5,  717,    7,  717,  717,
      717,  717,  717,  719,  720,  719,  717,  717,  717,  717,
      719,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  720,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  719,
      717,  717,  717,  719,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  720,

      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  719,  717,  717,  717,  717,  719,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  720,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  719,
      721,  722,  723,  720,  723,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,

      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  720,  720,  720,  720,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      724,  724,  717,  717,  717,  717,  717,  717,  717,  720,

      717,  720,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  725,  725,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  720,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  720,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,

      726,  717,  727,  727,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  720,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  720,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  728,  728,  717,
      717,  717,  720,  717,  717,  720,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,

      729,  730,  720,  720,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  731,  732,  733,  717,  720,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  734,  735,  736,  717,  720,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  737,  738,  739,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      740,  741,  742,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      743,  744,  745,  717,  717,  717,  717,  717,  717,  717,

      717,  717,  717,  717,  717,  746,  747,  748,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  749,  750,
      751,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      752,  753,  754,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  755,  756,  757,  717,  717,  717,  717,  758,
      759,  760,  717,  717,  761,  762,  763,  764,  765,  766,
      767,  768,  769,  770,  771,  772,  773,  774,  775,  776,
      777,  778,  779,  780,  781,  782,  783,  784,  785,  786,
      787,  788,  789,  790,  791,  792,  793,  794,  795,  796,
      797,  798,  799,  800,  801,  802,  803,  804,  805,  717,

      806,  807,  808,  809,  810,  811,  812,  813,  814,  815,
      816,  817,  717,  818,  819,  717,    0,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,

      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717
    } ;

static yyconst short int yy_nxt[1837] =
    {   0,
       10,   10,  717,  654,  717,  649,   12,   12,  648,  717,
       13,   13,   14,   16,  450,  450,  450,  450,  450,  450,
      450,  450,  450,  450,  450,  450,  450,  450,  450,  450,
      536,  717,  451,  452,  453,  453,  451,  452,  453,  717,
      451,  452,  453,  502,  451,  452,  540,  540,  502,  717,
      537,   15,   15,   17,   18,   18,   18,   18,   18,   12,
       18,   18,   18,   19,   20,   21,   18,   22,   18,   18,
       23,   18,   18,   18,   18,   18,   18,   18,   24,   25,
       26,   27,   28,   18,   29,   30,   31,   32,   33,   34,
       35,   36,   37,   38,   18,   39,   18,   40,   41,   18,

       18,   18,   18,   18,   42,   18,   43,   18,   44,   45,
       46,   47,   48,   49,   50,   51,   52,   53,   54,   55,
       56,   57,   58,   59,   60,   61,   62,   63,   64,   65,
       18,   66,   67,   18,   18,   68,   18,   69,   18,   18,
       71,   72,   72,   72,   72,   72,   12,   72,   72,   72,
       73,   72,   74,   72,   75,   72,   72,   72,   72,   72,
       72,   72,   72,   72,   72,   76,   77,   78,   79,   80,
       81,   82,   83,   84,   85,   86,   87,   88,   89,   90,
       91,   92,   93,   94,   95,   96,   97,   72,   98,   99,
       72,  100,   72,   72,   72,  101,  102,  103,  104,   80,

       81,  105,   83,   84,  106,  107,   87,   88,   89,  108,
      109,   92,   93,   94,  110,   96,   97,   72,   98,   99,
       72,   72,  111,   72,   72,   72,   72,  113,  114,  114,
      114,  114,  114,   12,  114,  114,  114,  115,  116,  117,
      114,  118,  114,  114,  119,  114,  114,  114,  114,  114,
      114,  114,  114,  120,  121,  122,  114,  114,  123,  124,
      114,  125,  126,  127,  114,  128,  114,  129,  114,  130,
      131,  132,  114,  114,  114,  114,  114,  114,  133,  114,
      114,  134,  135,  136,  137,  138,  139,  140,  141,  142,
      143,  144,  145,  146,  147,  148,  149,  150,  151,  152,

      153,  154,  155,  156,  156,  157,  158,  114,  114,  159,
      114,  114,  114,  114,  161,  161,  166,  202,  200,  217,
      161,  219,  220,  221,  222,  203,  223,  193,  201,  217,
      161,  218,  224,  536,  302,  226,  309,  204,  258,  227,
      310,  218,  647,  311,  646,  537,  167,  303,  647,  217,
      168,  219,  220,  221,  222,  259,  223,  169,  239,  170,
      171,  218,  224,  172,  173,  226,  194,  195,  196,  227,
      174,  197,  246,  247,  198,  300,  502,  646,  228,  240,
      335,  502,  229,  337,  230,  390,  241,  242,  243,  244,
      231,  255,  248,  301,  636,  162,  162,  175,  249,  245,

      176,  162,  250,  251,  536,  405,  252,  177,  178,  636,
      336,  162,  642,  338,  179,  391,  180,  256,  537,  471,
      472,  641,  474,  232,  257,  233,  262,  181,  630,  630,
      182,  636,  636,  183,  184,  406,  263,  185,  186,  187,
      188,  189,  234,  235,  190,  191,  192,  630,  264,  471,
      472,  236,  474,  475,  630,  609,  477,  265,  278,  279,
      280,  280,  280,  281,  630,  282,  283,  283,  283,  283,
      284,  283,  283,  285,  283,  286,  283,  287,  283,  288,
      283,  283,  283,  475,  325,  350,  477,  625,  386,  351,
      352,  530,  530,  530,  530,  326,  353,  327,  387,  283,

      548,  328,  610,  283,  283,  283,  283,  283,  329,  339,
      531,  289,  536,  340,  330,  354,  545,  341,  388,  355,
      356,  545,  618,  342,  617,  331,  357,  332,  389,  343,
      549,  333,  537,  537,  575,  344,  378,  616,  334,  345,
      615,  614,  483,  346,  379,  380,  381,  347,  478,  479,
      613,  612,  480,  348,  536,  481,  540,  540,  540,  349,
      359,  611,  595,  360,  576,  471,  382,  361,  537,  537,
      537,  362,  363,  364,  383,  384,  385,  365,  366,  367,
      450,  450,  450,  450,  634,  471,  532,  532,  532,  532,
      368,  545,  596,  369,  453,  545,  545,  370,  451,  452,

      545,  371,  372,  373,  531,  471,  605,  374,  375,  376,
      450,  450,  450,  450,  635,  604,  545,  450,  450,  450,
      450,  545,  454,  603,  453,  453,  453,  456,  451,  452,
      457,  602,  458,  462,  459,  460,  461,  545,  463,  545,
      601,  464,  545,  465,  545,  466,  545,  467,  478,  479,
      600,  545,  480,  599,  598,  481,  533,  533,  533,  533,
      597,  538,  530,  530,  530,  539,  532,  532,  532,  622,
      594,  545,  482,  585,  534,  535,  545,  581,  478,  479,
      531,  574,  480,  531,  623,  481,  577,  577,  577,  577,
      578,  578,  578,  578,  580,  580,  580,  580,  582,  582,

      582,  582,  570,  586,  626,  626,  626,  626,  587,  579,
      569,  588,  579,  589,  624,  590,  583,  584,  627,  627,
      627,  627,  629,  629,  629,  629,  630,  630,  630,  637,
      568,  545,  567,  545,  545,  638,  545,  628,  545,  545,
      628,  653,  653,  653,  653,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  639,
      545,  545,  545,  545,  545,  640,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  545,  545,  545,  545,  566,  545,
      565,  545,  545,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,  163,  163,  564,  563,  163,  164,
      164,  563,  164,  277,  277,  277,  277,  277,  277,  277,
      277,  277,  277,  277,  290,  290,  290,  563,  290,  290,
      290,  290,  290,  290,  290,  291,  291,  562,  561,  291,
      322,  322,  557,  556,  322,  403,  403,  555,  554,  403,
      455,  455,  455,  455,  455,  455,  468,  468,  553,  552,
      468,  501,  501,  551,  550,  501,  524,  524,  547,  546,
      524,  525,  525,  525,  542,  525,  525,  525,  525,  525,
      525,  525,  541,  541,  541,  540,  541,  543,  543,  540,
      540,  543,  544,  544,  544,  536,  544,  544,  544,  544,

      544,  544,  544,  558,  558,  529,  528,  558,  559,  559,
      559,  527,  559,  559,  559,  559,  559,  559,  559,  560,
      560,  560,  526,  560,  560,  560,  560,  560,  560,  560,
      571,  571,  523,  522,  571,  572,  572,  572,  521,  572,
      572,  572,  572,  572,  572,  572,  573,  573,  520,  519,
      573,  518,  573,  573,  573,  573,  573,  591,  591,  517,
      516,  591,  592,  592,  592,  515,  592,  592,  592,  592,
      592,  592,  592,  593,  593,  514,  513,  593,  512,  593,
      593,  593,  593,  593,  606,  606,  511,  510,  606,  607,
      607,  607,  509,  607,  607,  607,  607,  607,  607,  607,

      608,  608,  508,  507,  608,  506,  608,  608,  608,  608,
      608,  619,  619,  505,  504,  619,  620,  620,  620,  503,
      620,  620,  620,  620,  620,  620,  620,  621,  621,  500,
      499,  621,  498,  621,  621,  621,  621,  621,  631,  631,
      497,  496,  631,  632,  632,  632,  495,  632,  632,  632,
      632,  632,  632,  632,  633,  633,  494,  493,  633,  492,
      633,  633,  633,  633,  633,  643,  643,  491,  490,  643,
      644,  644,  644,  489,  644,  644,  644,  644,  644,  644,
      644,  645,  645,  488,  487,  645,  486,  645,  645,  645,
      645,  645,  650,  650,  485,  484,  650,  651,  651,  651,

      470,  651,  651,  651,  651,  651,  651,  651,  652,  652,
      477,  476,  652,  475,  652,  652,  652,  652,  652,  655,
      655,  474,  473,  655,  656,  656,  656,  472,  656,  656,
      656,  656,  656,  656,  656,  657,  657,  471,  416,  657,
      470,  657,  657,  657,  657,  657,  658,  658,  470,  469,
      658,  659,  659,  659,  449,  659,  659,  659,  659,  659,
      659,  659,  660,  660,  448,  447,  660,  447,  660,  660,
      660,  660,  660,  661,  661,  446,  445,  661,  662,  662,
      662,  446,  662,  662,  662,  662,  662,  662,  662,  663,
      663,  445,  442,  663,  444,  663,  663,  663,  663,  663,

      664,  664,  443,  439,  664,  665,  665,  665,  442,  665,
      665,  665,  665,  665,  665,  665,  666,  666,  441,  440,
      666,  439,  666,  666,  666,  666,  666,  667,  667,  438,
      437,  667,  668,  668,  668,  434,  668,  668,  668,  668,
      668,  668,  668,  669,  669,  433,  432,  669,  431,  669,
      669,  669,  669,  669,  670,  670,  430,  429,  670,  671,
      671,  671,  436,  671,  671,  671,  671,  671,  671,  671,
      672,  672,  427,  435,  672,  434,  672,  672,  672,  672,
      672,  673,  673,  433,  432,  673,  674,  674,  674,  431,
      674,  674,  674,  674,  674,  674,  674,  675,  675,  430,

      429,  675,  428,  675,  675,  675,  675,  675,  676,  676,
      427,  426,  676,  677,  677,  677,  425,  677,  677,  677,
      677,  677,  677,  677,  678,  678,  422,  424,  678,  420,
      678,  678,  678,  678,  678,  679,  679,  423,  422,  679,
      680,  680,  680,  421,  680,  680,  680,  680,  680,  680,
      680,  681,  681,  420,  418,  681,  417,  681,  681,  681,
      681,  681,  682,  682,  416,  415,  682,  683,  683,  683,
      414,  683,  683,  683,  683,  683,  683,  683,  684,  684,
      419,  418,  684,  417,  684,  684,  684,  684,  684,  685,
      685,  416,  415,  685,  686,  686,  686,  414,  686,  686,

      686,  686,  686,  686,  686,  687,  687,  413,  413,  687,
      412,  687,  687,  687,  687,  687,  688,  688,  412,  411,
      688,  689,  689,  689,  410,  689,  689,  689,  689,  689,
      689,  689,  690,  690,  409,  408,  690,  407,  690,  690,
      690,  690,  690,  691,  691,  411,  410,  691,  692,  692,
      692,  409,  692,  692,  692,  692,  692,  692,  692,  693,
      693,  408,  407,  693,  404,  693,  693,  693,  693,  693,
      694,  694,  402,  401,  694,  695,  695,  695,  400,  695,
      695,  695,  695,  695,  695,  695,  696,  696,  399,  398,
      696,  397,  696,  696,  696,  696,  696,  697,  697,  396,

      395,  697,  698,  698,  698,  394,  698,  698,  698,  698,
      698,  698,  698,  699,  699,  393,  392,  699,  377,  699,
      699,  699,  699,  699,  700,  700,  358,  324,  700,  701,
      701,  701,  323,  701,  701,  701,  701,  701,  701,  701,
      702,  702,  321,  320,  702,  319,  702,  702,  702,  702,
      702,  703,  703,  703,  318,  703,  703,  703,  703,  703,
      703,  703,  704,  704,  317,  316,  704,  315,  704,  704,
      704,  704,  704,  705,  705,  705,  314,  705,  705,  705,
      705,  705,  705,  705,  706,  706,  313,  312,  706,  246,
      706,  706,  706,  706,  706,  707,  707,  707,  308,  707,

      707,  707,  707,  707,  707,  707,  708,  708,  307,  306,
      708,  305,  708,  708,  708,  708,  708,  709,  709,  709,
      304,  709,  709,  709,  709,  709,  709,  709,  710,  710,
      299,  298,  710,  297,  710,  710,  710,  710,  710,  711,
      711,  711,  296,  711,  711,  711,  711,  711,  711,  711,
      712,  712,  295,  294,  712,  293,  712,  712,  712,  712,
      712,  713,  713,  713,  180,  713,  713,  713,  713,  713,
      713,  713,  714,  714,  177,  176,  714,  166,  714,  714,
      714,  714,  714,  715,  715,  166,  292,  715,  165,  715,
      715,  715,  715,  715,  716,  716,  276,  275,  716,  274,

      716,  716,  716,  716,  716,  273,  272,  271,  270,  269,
      268,  267,  266,  261,  260,  254,  253,  165,  238,  227,
      226,  237,  224,  223,  222,  221,  220,  219,  225,  165,
      216,  215,  214,  213,  212,  211,  210,  209,  208,  207,
      206,  205,  199,  165,  717,  160,  112,   70,    9,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,

      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717
    } ;

static yyconst short int yy_chk[1837] =
    {   0,
        1,    2,    0,  649,    0,  642,    1,    2,  641,    0,
        1,    2,    1,    2,  395,  395,  395,  395,  396,  396,
      396,  396,  399,  399,  399,  399,  397,  397,  397,  397,
      514,    0,  395,  395,  395,  395,  396,  396,  397,    0,
      399,  399,  399,  469,  397,  397,  518,  518,  469,    0,
      514,    1,    2,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,

        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,

        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,

        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,   10,   17,   20,   44,   43,   76,
       71,   77,   78,   79,   82,   44,   85,   36,   43,  101,
      113,   76,   86,  512,  234,   91,  243,   44,  130,   95,
      243,  101,  640,  243,  639,  512,   20,  234,  638,   76,
       20,   77,   78,   79,   82,  130,   85,   20,  116,   20,
       20,   76,   86,   20,   20,   91,   36,   36,   36,   95,
       20,   36,  119,  119,   36,  233,  502,  637,  100,  116,
      296,  502,  100,  297,  100,  305,  116,  116,  116,  116,
      100,  128,  119,  233,  635,   10,   17,   23,  119,  116,

       23,   71,  119,  119,  513,  324,  119,   23,   23,  634,
      296,  113,  630,  297,   23,  305,   23,  128,  513,  421,
      423,  628,  428,  100,  128,  100,  135,   23,  614,  614,
       23,  624,  623,   23,   23,  324,  135,   23,   23,   23,
       23,   23,  100,  100,   23,   23,   23,  617,  135,  421,
      423,  100,  428,  435,  616,  594,  440,  135,  161,  161,
      161,  161,  161,  161,  615,  161,  161,  161,  161,  161,
      161,  161,  161,  161,  161,  161,  161,  161,  161,  161,
      161,  161,  161,  435,  295,  299,  440,  610,  304,  299,
      299,  507,  507,  507,  507,  295,  299,  295,  304,  161,

      528,  295,  594,  161,  161,  161,  161,  161,  295,  298,
      507,  161,  510,  298,  295,  299,  525,  298,  304,  299,
      299,  525,  605,  298,  604,  295,  299,  295,  304,  298,
      528,  295,  510,  510,  562,  298,  303,  603,  295,  298,
      602,  601,  444,  298,  303,  303,  303,  298,  444,  444,
      600,  599,  444,  298,  515,  444,  522,  522,  522,  298,
      301,  598,  575,  301,  562,  597,  303,  301,  515,  515,
      515,  301,  301,  301,  303,  303,  303,  301,  301,  301,
      398,  398,  398,  398,  622,  596,  508,  508,  508,  508,
      301,  544,  575,  301,  398,  545,  544,  301,  398,  398,

      545,  301,  301,  301,  508,  595,  590,  301,  301,  301,
      400,  400,  400,  400,  622,  589,  559,  401,  401,  401,
      401,  559,  401,  588,  400,  400,  400,  401,  400,  400,
      401,  587,  401,  402,  401,  401,  401,  572,  402,  592,
      586,  402,  572,  402,  592,  402,  607,  402,  441,  441,
      584,  607,  441,  583,  579,  441,  509,  509,  509,  509,
      576,  516,  516,  516,  516,  517,  517,  517,  517,  609,
      574,  620,  441,  569,  509,  509,  620,  567,  441,  441,
      516,  561,  441,  517,  609,  441,  564,  564,  564,  564,
      565,  565,  565,  565,  566,  566,  566,  566,  568,  568,

      568,  568,  557,  570,  611,  611,  611,  611,  570,  565,
      556,  570,  566,  570,  609,  570,  568,  568,  612,  612,
      612,  612,  613,  613,  613,  613,  618,  618,  618,  625,
      555,  632,  554,  644,  651,  625,  632,  612,  644,  651,
      613,  648,  648,  648,  648,  656,  659,  662,  665,  668,
      656,  659,  662,  665,  668,  671,  674,  677,  680,  625,
      671,  674,  677,  680,  683,  625,  686,  689,  692,  683,
      695,  686,  689,  692,  698,  695,  701,  703,  705,  698,
      707,  701,  703,  705,  709,  707,  711,  713,  553,  709,
      552,  711,  713,  718,  718,  718,  718,  718,  718,  718,

      718,  718,  718,  718,  719,  719,  551,  550,  719,  720,
      720,  549,  720,  721,  721,  721,  721,  721,  721,  721,
      721,  721,  721,  721,  722,  722,  722,  548,  722,  722,
      722,  722,  722,  722,  722,  723,  723,  547,  546,  723,
      724,  724,  542,  541,  724,  725,  725,  540,  537,  725,
      726,  726,  726,  726,  726,  726,  727,  727,  535,  534,
      727,  728,  728,  531,  529,  728,  729,  729,  527,  526,
      729,  730,  730,  730,  523,  730,  730,  730,  730,  730,
      730,  730,  731,  731,  731,  521,  731,  732,  732,  520,
      519,  732,  733,  733,  733,  511,  733,  733,  733,  733,

      733,  733,  733,  734,  734,  506,  505,  734,  735,  735,
      735,  504,  735,  735,  735,  735,  735,  735,  735,  736,
      736,  736,  503,  736,  736,  736,  736,  736,  736,  736,
      737,  737,  500,  499,  737,  738,  738,  738,  498,  738,
      738,  738,  738,  738,  738,  738,  739,  739,  497,  496,
      739,  495,  739,  739,  739,  739,  739,  740,  740,  494,
      493,  740,  741,  741,  741,  492,  741,  741,  741,  741,
      741,  741,  741,  742,  742,  491,  490,  742,  489,  742,
      742,  742,  742,  742,  743,  743,  488,  487,  743,  744,
      744,  744,  486,  744,  744,  744,  744,  744,  744,  744,

      745,  745,  485,  484,  745,  483,  745,  745,  745,  745,
      745,  746,  746,  482,  476,  746,  747,  747,  747,  473,
      747,  747,  747,  747,  747,  747,  747,  748,  748,  467,
      466,  748,  465,  748,  748,  748,  748,  748,  749,  749,
      464,  463,  749,  750,  750,  750,  462,  750,  750,  750,
      750,  750,  750,  750,  751,  751,  461,  460,  751,  459,
      751,  751,  751,  751,  751,  752,  752,  458,  457,  752,
      753,  753,  753,  456,  753,  753,  753,  753,  753,  753,
      753,  754,  754,  455,  454,  754,  453,  754,  754,  754,
      754,  754,  755,  755,  452,  451,  755,  756,  756,  756,

      448,  756,  756,  756,  756,  756,  756,  756,  757,  757,
      443,  438,  757,  437,  757,  757,  757,  757,  757,  758,
      758,  436,  426,  758,  759,  759,  759,  425,  759,  759,
      759,  759,  759,  759,  759,  760,  760,  424,  419,  760,
      406,  760,  760,  760,  760,  760,  761,  761,  405,  404,
      761,  762,  762,  762,  393,  762,  762,  762,  762,  762,
      762,  762,  763,  763,  392,  391,  763,  390,  763,  763,
      763,  763,  763,  764,  764,  389,  388,  764,  765,  765,
      765,  387,  765,  765,  765,  765,  765,  765,  765,  766,
      766,  386,  385,  766,  384,  766,  766,  766,  766,  766,

      767,  767,  383,  382,  767,  768,  768,  768,  381,  768,
      768,  768,  768,  768,  768,  768,  769,  769,  380,  379,
      769,  378,  769,  769,  769,  769,  769,  770,  770,  377,
      376,  770,  771,  771,  771,  375,  771,  771,  771,  771,
      771,  771,  771,  772,  772,  374,  373,  772,  372,  772,
      772,  772,  772,  772,  773,  773,  371,  370,  773,  774,
      774,  774,  369,  774,  774,  774,  774,  774,  774,  774,
      775,  775,  368,  367,  775,  366,  775,  775,  775,  775,
      775,  776,  776,  365,  364,  776,  777,  777,  777,  363,
      777,  777,  777,  777,  777,  777,  777,  778,  778,  362,

      361,  778,  360,  778,  778,  778,  778,  778,  779,  779,
      359,  358,  779,  780,  780,  780,  357,  780,  780,  780,
      780,  780,  780,  780,  781,  781,  356,  355,  781,  354,
      781,  781,  781,  781,  781,  782,  782,  353,  352,  782,
      783,  783,  783,  351,  783,  783,  783,  783,  783,  783,
      783,  784,  784,  350,  349,  784,  348,  784,  784,  784,
      784,  784,  785,  785,  347,  346,  785,  786,  786,  786,
      345,  786,  786,  786,  786,  786,  786,  786,  787,  787,
      344,  343,  787,  342,  787,  787,  787,  787,  787,  788,
      788,  341,  340,  788,  789,  789,  789,  339,  789,  789,

      789,  789,  789,  789,  789,  790,  790,  338,  337,  790,
      336,  790,  790,  790,  790,  790,  791,  791,  335,  334,
      791,  792,  792,  792,  333,  792,  792,  792,  792,  792,
      792,  792,  793,  793,  332,  331,  793,  330,  793,  793,
      793,  793,  793,  794,  794,  329,  328,  794,  795,  795,
      795,  327,  795,  795,  795,  795,  795,  795,  795,  796,
      796,  326,  325,  796,  323,  796,  796,  796,  796,  796,
      797,  797,  321,  320,  797,  798,  798,  798,  319,  798,
      798,  798,  798,  798,  798,  798,  799,  799,  318,  317,
      799,  316,  799,  799,  799,  799,  799,  800,  800,  315,

      314,  800,  801,  801,  801,  310,  801,  801,  801,  801,
      801,  801,  801,  802,  802,  309,  306,  802,  302,  802,
      802,  802,  802,  802,  803,  803,  300,  294,  803,  804,
      804,  804,  292,  804,  804,  804,  804,  804,  804,  804,
      805,  805,  289,  288,  805,  287,  805,  805,  805,  805,
      805,  806,  806,  806,  286,  806,  806,  806,  806,  806,
      806,  806,  807,  807,  285,  284,  807,  283,  807,  807,
      807,  807,  807,  808,  808,  808,  282,  808,  808,  808,
      808,  808,  808,  808,  809,  809,  262,  258,  809,  250,
      809,  809,  809,  809,  809,  810,  810,  810,  242,  810,

      810,  810,  810,  810,  810,  810,  811,  811,  239,  237,
      811,  236,  811,  811,  811,  811,  811,  812,  812,  812,
      235,  812,  812,  812,  812,  812,  812,  812,  813,  813,
      232,  231,  813,  230,  813,  813,  813,  813,  813,  814,
      814,  814,  229,  814,  814,  814,  814,  814,  814,  814,
      815,  815,  228,  225,  815,  193,  815,  815,  815,  815,
      815,  816,  816,  816,  192,  816,  816,  816,  816,  816,
      816,  816,  817,  817,  185,  182,  817,  175,  817,  817,
      817,  817,  817,  818,  818,  167,  165,  818,  160,  818,
      818,  818,  818,  818,  819,  819,  159,  155,  819,  154,

      819,  819,  819,  819,  819,  153,  149,  145,  143,  141,
      139,  138,  137,  132,  131,  122,  121,  112,  111,  110,
      109,  108,  107,  106,  105,  104,  103,  102,   90,   70,
       69,   68,   64,   63,   59,   54,   53,   52,   50,   47,
       46,   45,   39,   16,    9,    8,    6,    4,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,

      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717,  717,  717,  717,  717,
      717,  717,  717,  717,  717,  717
    } ;

static yy_state_type yy_state_buf[YY_BUF_SIZE + 2], *yy_state_ptr;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yy_full_match; /* restore poss. backed-over text */ \
++yy_lp; \
goto find_rule; \
}
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
char *yytext;
#line 1 "indica.lex"
#define INITIAL 0
/*
 * Modified by Vasantha Saparamadu <vsaparam@ocs.mq.edu.au>
 * 08 January 1996
 */
#line 8 "indica.lex"
#define VERSION "2.1"

#define BOOLEAN char
#define UNSIGNED_BYTE unsigned char
#define SIGNED_BYTE signed char
#define TRUE 1
#define FALSE 0
#define DEBUG_PROMPT "\n%DEBUG:" 
#define HASH_TABLE_SIZE 251
#define MAX_COMMAND_NAME_LENGTH 32

#define ANUSVARA 2
#define VISARGA 3
#define VOW_A 4
#define VOW_AA 5
#define VOW_AAA 6
#define VOW_AAAA 7
#define VOW_I 8
#define VOW_II 9
#define VOW_U 10
#define VOW_UU 11
#define VOW_R 12
#define VOW_RR 13
#define VOW_L 14
#define VOW_LL 15
#define CANDRA_E 16
#define VOW_E 17
#define VOW_EE 18
#define VOW_AI 19
#define CANDRA_O 20
#define VOW_O 21
#define VOW_OO 22
#define VOW_AU 23
#define CON_K 30
#define CON_KH 31
#define CON_G 32
#define CON_GH 33
#define CON_NG 34
#define CON_C 35
#define CON_CH 36
#define CON_J 37
#define CON_JH 38
#define CON_NY 39
#define CON_TT 40
#define CON_TTH 41
#define CON_DD 42
#define CON_DDH 43
#define CON_NN 44
#define CON_T 45
#define CON_TH 46
#define CON_D 47
#define CON_DH 48
#define CON_N 49
#define CON_NNN 50
#define CON_P 51
#define CON_PH 52
#define CON_B 53
#define CON_BH 54
#define CON_M 55
#define CON_Y 56
#define CON_R 57
#define CON_RR 58
#define CON_L 59
#define CON_LL 60
#define CON_V 61
#define CON_SH 62
#define CON_SS 63
#define CON_S 64
#define CON_H 65
#define NUKTA 66
#define AVAGRAHA 67
#define VIRAMA 68
#define OM 69
#define UDATTA 70
#define ANUDATTA 71
#define GRAVE 72
#define ACUTE 73
#define LENGTH_MARK 74
#define AI_LENGTH_MARK 75
#define CON_Q 76
#define CON_KKH 77
#define CON_GHH 78
#define CON_Z 79
#define CON_DDDH 80
#define CON_RH 81
#define CON_F 82
#define CON_YY 83
#define VBAR 84
#define VBARVBAR 85
#define CON_NAS_G 86
#define CON_NAS_C 87
#define CON_NAS_DD 88
#define CON_NAS_D 89
#define CON_NAS_B 90
#define CON_NAS_J 91
#define CON_KS 92
#define CON_LLL 93
#define CANDRABINDU 94
#define BANDI 95

#define HINDI 1
#define SANSKRIT 2
#define BENGALI 3
#define GURMUKHI 4
#define ORIYA 5
#define TAMIL 6
#define TELUGU 7
#define KANNADA 8
#define SINHALESE 9
#define SINHALA 9
#define GUJARATI 10
#define MALAYALAM 11
#define TIBETAN 12


typedef struct{
char name[MAX_COMMAND_NAME_LENGTH];
UNSIGNED_BYTE ID;
} command_type;
command_type cur_command;

unsigned char *token,string[33] = "",buffer[1024];
int current_buffer_position = 0;
int current_line=1;

BOOLEAN debug = FALSE;
int i=0;

typedef struct hash_list*hash_list_pointer;
struct hash_list{
command_type command;
hash_list_pointer link;};
hash_list_pointer hash_table[HASH_TABLE_SIZE];

int current_language = 0, current_input_mode = 1;
BOOLEAN already_read = FALSE, r_con_a = FALSE, sh_hyphens_activated = FALSE;


void hash_insert(command_type);
unsigned int hash(char*);
int look_in_hash(char[]);
void put_indic(int);
void put_other(unsigned char);
void release_buffer(void);
void sh_cons_vow(int, int, int);
void sh_ra_cons_a(int);
void sh_lig_vow(int, int, int, int);
void sh_ra_lig_a(int, int);

#define SEVENBIT 1

#define LATEX 2

#define SAMANALA 3

#line 1275 "lex.yy.c"

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap YY_PROTO(( void ));
#else
extern int yywrap YY_PROTO(( void ));
#endif
#endif

#ifndef YY_NO_UNPUT
static void yyunput YY_PROTO(( int c, char *buf_ptr ));
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy YY_PROTO(( char *, yyconst char *, int ));
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput YY_PROTO(( void ));
#else
static int input YY_PROTO(( void ));
#endif
#endif

#if YY_STACK_USED
static int yy_start_stack_ptr = 0;
static int yy_start_stack_depth = 0;
static int *yy_start_stack = 0;
#ifndef YY_NO_PUSH_STATE
static void yy_push_state YY_PROTO(( int new_state ));
#endif
#ifndef YY_NO_POP_STATE
static void yy_pop_state YY_PROTO(( void ));
#endif
#ifndef YY_NO_TOP_STATE
static int yy_top_state YY_PROTO(( void ));
#endif

#else
#define YY_NO_PUSH_STATE 1
#define YY_NO_POP_STATE 1
#define YY_NO_TOP_STATE 1
#endif

#ifdef YY_MALLOC_DECL
YY_MALLOC_DECL
#else
#if __STDC__
#ifndef __cplusplus
#include <stdlib.h>
#endif
#else
/* Just try to get by without declaring the routines.  This will fail
 * miserably on non-ANSI systems for which sizeof(size_t) != sizeof(int)
 * or sizeof(void*) != sizeof(int).
 */
#endif
#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */

#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( yy_current_buffer->yy_is_interactive ) \
		{ \
		int c = '*', n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else if ( ((result = fread( buf, 1, max_size, yyin )) == 0) \
		  && ferror( yyin ) ) \
		YY_FATAL_ERROR( "input in flex scanner failed" );
#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL int yylex YY_PROTO(( void ))
#endif

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		yy_current_buffer->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

YY_DECL
	{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;

#line 171 "indica.lex"


#line 1428 "lex.yy.c"

	if ( yy_init )
		{
		yy_init = 0;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yy_start )
			yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! yy_current_buffer )
			yy_current_buffer =
				yy_create_buffer( yyin, YY_BUF_SIZE );

		yy_load_buffer_state();
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yy_start;
		yy_current_state += YY_AT_BOL();
		yy_state_ptr = yy_state_buf;
		*yy_state_ptr++ = yy_current_state;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 718 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1749 );

yy_find_action:
		yy_current_state = *--yy_state_ptr;
		yy_lp = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yy_lp && yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yy_lp];
					{
					yy_full_match = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--yy_state_ptr;
			yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;


do_action:	/* This label is used only to access EOF actions. */


		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
YY_RULE_SETUP
#line 173 "indica.lex"
{ 
								token = (unsigned char*) strtok(yytext," \t"); /* #def */
								token = (unsigned char*) strtok(NULL," \t"); /* first argument */
								if ((cur_command.ID = look_in_hash(token)) != -1) {
									token = (unsigned char*) strtok(NULL," \t"); /* second argument */
									strcpy(cur_command.name,token);
									hash_insert(cur_command);
									}
								}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 183 "indica.lex"
{ for (i=1;i<yyleng;i++) string[i-1] = yytext[i]; string[yyleng-1] = 0x00;
									i = look_in_hash(string);
									switch (i) {
										case -1: printf("#"); yyless(1); if (debug==TRUE) { 
												printf("%s couldn't find %s in the hash table, putting it back",
												DEBUG_PROMPT,string); } break;
										case 1: printf("#"); yyless(1); if (debug==TRUE) { 
												printf("%s not the right syntax for #alias, putting it back",
												DEBUG_PROMPT,string); } break;
										case 10: if (debug==TRUE) { printf("%s Starting UNICODE mode",
												DEBUG_PROMPT,string); } break;
										case 11: if (debug==TRUE) { printf("%s Starting 7 BIT mode",
												DEBUG_PROMPT,string); } 
												current_input_mode = SEVENBIT;
												break;
										case 12: if (debug==TRUE) { printf("%s Starting CSX mode",
												DEBUG_PROMPT,string); } break;
										case 13: if (debug==TRUE) { printf("%s Starting LaTeX mode",
												DEBUG_PROMPT,string); } 
												current_input_mode = LATEX;
												break;
										case 14: if (debug==TRUE) { printf("%s Starting samanala mode",
												DEBUG_PROMPT,string); } 
												current_input_mode = SAMANALA;
												break;
										case 20: if (debug==TRUE) { printf("%s Starting NIL mode",
												DEBUG_PROMPT,string); } 
												current_language = 0; BEGIN 0; release_buffer();
												break;
										case 21: if (debug==TRUE) { printf("%s Starting HINDI mode",
												DEBUG_PROMPT,string); } 
												current_language = HINDI; 
												BEGIN current_input_mode;
												break;
										case 22: if (debug==TRUE) { printf("%s Starting SANSKRIT mode",
												DEBUG_PROMPT,string); } 
												current_language = SANSKRIT; 
												BEGIN current_input_mode;
												break;
										case 23: if (debug==TRUE) { printf("%s Starting BENGALI mode",
												DEBUG_PROMPT,string); } 
												current_language = BENGALI; 
												BEGIN current_input_mode;
												break;
										case 24: if (debug==TRUE) { printf("%s Starting GURMUKHI mode",
												DEBUG_PROMPT,string); } 
												current_language = GURMUKHI; 
												BEGIN current_input_mode;
												break;
										case 25: if (debug==TRUE) { printf("%s Starting GUJARATI mode",
												DEBUG_PROMPT,string); } 
												current_language = GUJARATI; 
												BEGIN current_input_mode;
												break;
										case 26: if (debug==TRUE) { printf("%s Starting TAMIL mode",
												DEBUG_PROMPT,string); } 
												current_language = TAMIL; 
												BEGIN current_input_mode;
												break;
										case 27: if (debug==TRUE) { printf("%s Starting TELUGU mode",
												DEBUG_PROMPT,string); } 
												current_language = TELUGU; 
												BEGIN current_input_mode;
												break;
										case 28: if (debug==TRUE) { printf("%s Starting KANNADA mode",
												DEBUG_PROMPT,string); } 
												current_language = KANNADA; 
												BEGIN current_input_mode;
												break;
										case 29: if (debug==TRUE) { printf("%s Starting MALAYALAM mode",
												DEBUG_PROMPT,string); } 
												current_language = MALAYALAM; 
												BEGIN current_input_mode;
												break;
										case 30: if (debug==TRUE) { printf("%s Starting ORIYA mode",
												DEBUG_PROMPT,string); } 
												current_language = ORIYA; 
												BEGIN current_input_mode;
												break;
										case 31: if (debug==TRUE) { printf("%s Starting SINHALESE mode",
												DEBUG_PROMPT,string); } 
												current_language = SINHALESE; 
												BEGIN current_input_mode;
												break;
										default: break;
										}
									}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 271 "indica.lex"
{ if (already_read == FALSE)  { yyless(0); release_buffer(); already_read = TRUE; }
									else { ECHO; already_read = FALSE; }}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 274 "indica.lex"
{ if (already_read == FALSE)  { yyless(0); release_buffer(); already_read = TRUE; }
									else { ECHO; already_read = FALSE; current_line++; }}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 277 "indica.lex"
{ put_indic(ANUSVARA); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 279 "indica.lex"
{ put_indic(VISARGA); }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 281 "indica.lex"
{ put_indic(VOW_A); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 283 "indica.lex"
{ put_indic(VOW_AA); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 285 "indica.lex"
{ put_indic(VOW_AAA); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 287 "indica.lex"
{ put_indic(VOW_AAAA); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 289 "indica.lex"
{ put_indic(VOW_I); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 291 "indica.lex"
{ put_indic(VOW_II); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 293 "indica.lex"
{ put_indic(VOW_U); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 295 "indica.lex"
{ put_indic(VOW_UU); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 297 "indica.lex"
{ put_indic(VOW_R); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 299 "indica.lex"
{ put_indic(VOW_RR); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 301 "indica.lex"
{ put_indic(VOW_L); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 303 "indica.lex"
{ put_indic(VOW_LL); }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 305 "indica.lex"
{ put_indic(CANDRA_E); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 307 "indica.lex"
{ put_indic(VOW_E); }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 309 "indica.lex"
{ put_indic(VOW_EE); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 311 "indica.lex"
{ put_indic(VOW_AI); }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 313 "indica.lex"
{ put_indic(CANDRA_O); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 315 "indica.lex"
{ put_indic(VOW_O); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 317 "indica.lex"
{ put_indic(VOW_OO); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 319 "indica.lex"
{ put_indic(VOW_AU); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 321 "indica.lex"
{ put_indic(CON_K); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 323 "indica.lex"
{ put_indic(CON_KH); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 325 "indica.lex"
{ put_indic(CON_G); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 327 "indica.lex"
{ put_indic(CON_GH); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 329 "indica.lex"
{ put_indic(CON_NG); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 331 "indica.lex"
{ put_indic(CON_C); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 333 "indica.lex"
{ put_indic(CON_CH); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 335 "indica.lex"
{ put_indic(CON_J); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 337 "indica.lex"
{ put_indic(CON_JH); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 339 "indica.lex"
{ put_indic(CON_NY); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 341 "indica.lex"
{ put_indic(CON_TT); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 343 "indica.lex"
{ put_indic(CON_TTH); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 345 "indica.lex"
{ put_indic(CON_DD); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 347 "indica.lex"
{ put_indic(CON_DDH); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 349 "indica.lex"
{ put_indic(CON_NN); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 351 "indica.lex"
{ put_indic(CON_T); }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 353 "indica.lex"
{ put_indic(CON_TH); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 355 "indica.lex"
{ put_indic(CON_D); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 357 "indica.lex"
{ put_indic(CON_DH); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 359 "indica.lex"
{ put_indic(CON_N); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 361 "indica.lex"
{ put_indic(CON_NNN); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 363 "indica.lex"
{ put_indic(CON_P); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 365 "indica.lex"
{ put_indic(CON_PH); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 367 "indica.lex"
{ put_indic(CON_B); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 369 "indica.lex"
{ put_indic(CON_BH); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 371 "indica.lex"
{ put_indic(CON_M); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 373 "indica.lex"
{ put_indic(CON_Y); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 375 "indica.lex"
{ put_indic(CON_R); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 377 "indica.lex"
{ put_indic(CON_RR); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 379 "indica.lex"
{ put_indic(CON_L); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 381 "indica.lex"
{ put_indic(CON_LL); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 383 "indica.lex"
{ put_indic(CON_LLL); }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 385 "indica.lex"
{ put_indic(CON_V); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 387 "indica.lex"
{ put_indic(CON_SH); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 389 "indica.lex"
{ put_indic(CON_SS); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 391 "indica.lex"
{ put_indic(CON_S); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 393 "indica.lex"
{ put_indic(CON_H); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 395 "indica.lex"
{ put_indic(AVAGRAHA); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 397 "indica.lex"
{ put_indic(VIRAMA); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 399 "indica.lex"
{ put_indic(OM); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 401 "indica.lex"
{ put_indic(CON_Q); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 403 "indica.lex"
{ put_indic(CON_KKH); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 405 "indica.lex"
{ put_indic(CON_GHH); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 407 "indica.lex"
{ put_indic(CON_DDDH); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 409 "indica.lex"
{ put_indic(CON_RH); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 411 "indica.lex"
{ put_indic(CON_F); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 413 "indica.lex"
{ put_indic(CON_YY); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 415 "indica.lex"
{ put_indic(VBAR); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 417 "indica.lex"
{ put_indic(VBARVBAR); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 419 "indica.lex"
{ put_indic(CON_NAS_G); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 421 "indica.lex"
{ put_indic(CON_NAS_C); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 423 "indica.lex"
{ put_indic(CON_NAS_DD); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 425 "indica.lex"
{ put_indic(CON_NAS_D); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 427 "indica.lex"
{ put_indic(CON_NAS_B); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 429 "indica.lex"
{ put_indic(CON_NAS_J); }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 431 "indica.lex"
{ put_indic(CON_KS); }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 433 "indica.lex"
{ put_other(yytext[0]); }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 435 "indica.lex"
{ put_indic(ANUSVARA); }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 437 "indica.lex"
{ put_indic(VISARGA); }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 439 "indica.lex"
{ put_indic(VOW_A); }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 441 "indica.lex"
{ put_indic(VOW_AA); }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 443 "indica.lex"
{ put_indic(VOW_AAA); }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 445 "indica.lex"
{ put_indic(VOW_AAAA); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 447 "indica.lex"
{ put_indic(VOW_I); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 449 "indica.lex"
{ put_indic(VOW_II); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 451 "indica.lex"
{ put_indic(VOW_U); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 453 "indica.lex"
{ put_indic(VOW_UU); }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 455 "indica.lex"
{ put_indic(VOW_R); }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 457 "indica.lex"
{ put_indic(VOW_RR); }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 459 "indica.lex"
{ put_indic(VOW_L); }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 461 "indica.lex"
{ put_indic(VOW_LL); }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 463 "indica.lex"
{ put_indic(CANDRA_E); }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 465 "indica.lex"
{ put_indic(VOW_E); }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 467 "indica.lex"
{ put_indic(VOW_EE); }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 469 "indica.lex"
{ put_indic(VOW_AI); }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 471 "indica.lex"
{ put_indic(CANDRA_O); }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 473 "indica.lex"
{ put_indic(VOW_O); }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 475 "indica.lex"
{ put_indic(VOW_OO); }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 477 "indica.lex"
{ put_indic(VOW_AU); }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 479 "indica.lex"
{ put_indic(CON_K); }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 481 "indica.lex"
{ put_indic(CON_KH); }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 483 "indica.lex"
{ put_indic(CON_G); }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 485 "indica.lex"
{ put_indic(CON_GH); }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 487 "indica.lex"
{ put_indic(CON_NG); put_indic(VOW_A); }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 489 "indica.lex"
{ put_indic(CON_C); }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 491 "indica.lex"
{ put_indic(CON_CH); }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 493 "indica.lex"
{ put_indic(CON_J); }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 495 "indica.lex"
{ put_indic(CON_JH); }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 497 "indica.lex"
{ put_indic(CON_NY); }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 499 "indica.lex"
{ put_indic(CON_TT); }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 501 "indica.lex"
{ put_indic(CON_TTH); }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 503 "indica.lex"
{ put_indic(CON_DD); }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 505 "indica.lex"
{ put_indic(CON_DDH); }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 507 "indica.lex"
{ put_indic(CON_NN); }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 509 "indica.lex"
{ put_indic(CON_T); }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 511 "indica.lex"
{ put_indic(CON_TH); }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 513 "indica.lex"
{ put_indic(CON_D); }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 515 "indica.lex"
{ put_indic(CON_DH); }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 517 "indica.lex"
{ put_indic(CON_N); }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 519 "indica.lex"
{ put_indic(CON_P); }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 521 "indica.lex"
{ put_indic(CON_PH); }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 523 "indica.lex"
{ put_indic(CON_B); }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 525 "indica.lex"
{ put_indic(CON_BH); }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 527 "indica.lex"
{ put_indic(CON_M); }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 529 "indica.lex"
{ put_indic(CON_Y); }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 531 "indica.lex"
{ put_indic(CON_R); }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 533 "indica.lex"
{ put_indic(CON_L); }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 535 "indica.lex"
{ put_indic(CON_LL); }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 537 "indica.lex"
{ put_indic(CON_LLL); }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 539 "indica.lex"
{ put_indic(CON_V); }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 541 "indica.lex"
{ put_indic(CON_SH); }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 543 "indica.lex"
{ put_indic(CON_SS); }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 545 "indica.lex"
{ put_indic(CON_S); }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 547 "indica.lex"
{ put_indic(CON_H); }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 549 "indica.lex"
{ put_indic(AVAGRAHA); }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 551 "indica.lex"
{ put_indic(VIRAMA); }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 553 "indica.lex"
{ put_indic(OM); }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 555 "indica.lex"
{ put_indic(CON_Q); }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 557 "indica.lex"
{ put_indic(CON_KKH); }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 559 "indica.lex"
{ put_indic(CON_GHH); }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 561 "indica.lex"
{ put_indic(CON_DDDH); }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 563 "indica.lex"
{ put_indic(CON_RH); }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 565 "indica.lex"
{ put_indic(CON_F); }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 567 "indica.lex"
{ put_indic(CON_YY); }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 569 "indica.lex"
{ put_indic(VBAR); }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 571 "indica.lex"
{ put_indic(VBARVBAR); }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 573 "indica.lex"
{ put_indic(CON_NAS_G); }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 575 "indica.lex"
{ put_indic(CON_NAS_C); }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 577 "indica.lex"
{ put_indic(CON_NAS_DD); }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 579 "indica.lex"
{ put_indic(CON_NAS_D); }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 581 "indica.lex"
{ put_indic(CON_NAS_B); }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 583 "indica.lex"
{ put_indic(CON_NAS_J); }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 585 "indica.lex"
{ put_indic(BANDI);
					  put_indic(CON_J);
					  put_indic(CON_NY); }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 589 "indica.lex"
{ put_indic(BANDI);
					  put_indic(CON_N);
					  put_indic(CON_D); }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 594 "indica.lex"
{ put_indic(CON_KS); }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 596 "indica.lex"
{ put_other('{'); put_other('}'); }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 598 "indica.lex"
{ put_indic(BANDI); }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 600 "indica.lex"
{ put_other(yytext[0]); }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 602 "indica.lex"
{ put_indic(ANUSVARA); }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 604 "indica.lex"
{ put_indic(VISARGA); }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 606 "indica.lex"
{ put_indic(VOW_A); }
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 608 "indica.lex"
{ put_indic(VOW_AA); }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 610 "indica.lex"
{ put_indic(VOW_AAA); }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 612 "indica.lex"
{ put_indic(VOW_AAAA); }
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 614 "indica.lex"
{ put_indic(VOW_I); }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 616 "indica.lex"
{ put_indic(VOW_II); }
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 618 "indica.lex"
{ put_indic(VOW_U); }
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 620 "indica.lex"
{ put_indic(VOW_UU); }
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 622 "indica.lex"
{ put_indic(VOW_R); }
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 624 "indica.lex"
{ put_indic(VOW_RR); }
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 626 "indica.lex"
{ put_indic(VOW_L); }
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 628 "indica.lex"
{ put_indic(VOW_LL); }
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 630 "indica.lex"
{ put_indic(CANDRA_E); }
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 632 "indica.lex"
{ put_indic(VOW_E); }
	YY_BREAK
/* <LATEX>e|E 					{ put_indic(VOW_EE); } original version */
/* Begin DW input coding for Somadasa; DW 15/7/94 */
case 181:
YY_RULE_SETUP
#line 637 "indica.lex"
{ put_indic(VOW_EE); }
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 639 "indica.lex"
{ put_indic(VOW_E); }
	YY_BREAK
/* End DW input coding */
case 183:
YY_RULE_SETUP
#line 643 "indica.lex"
{ put_indic(VOW_AI); }
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 645 "indica.lex"
{ put_indic(CANDRA_O); }
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 647 "indica.lex"
{ put_indic(VOW_O); }
	YY_BREAK
/* <LATEX>o|O					{ put_indic(VOW_OO); } original version */
/* Begin DW input coding for Somadasa; DW 15/7/94 */
case 186:
YY_RULE_SETUP
#line 652 "indica.lex"
{ put_indic(VOW_OO); }
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 654 "indica.lex"
{ put_indic(VOW_O); }
	YY_BREAK
/* End DW input coding */
case 188:
YY_RULE_SETUP
#line 658 "indica.lex"
{ put_indic(VOW_AU); }
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 660 "indica.lex"
{ put_indic(CON_K); }
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 662 "indica.lex"
{ put_indic(CON_KH); }
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 664 "indica.lex"
{ put_indic(CON_G); }
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 666 "indica.lex"
{ put_indic(CON_GH); }
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 668 "indica.lex"
{ put_indic(CON_NG); }
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 670 "indica.lex"
{ put_indic(CON_C); }
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 672 "indica.lex"
{ put_indic(CON_CH); }
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 674 "indica.lex"
{ put_indic(CON_J); }
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 676 "indica.lex"
{ put_indic(CON_JH); }
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 678 "indica.lex"
{ put_indic(CON_NY); }
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 680 "indica.lex"
{ put_indic(CON_TT); }
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 682 "indica.lex"
{ put_indic(CON_TTH); }
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 684 "indica.lex"
{ put_indic(CON_DD); }
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 686 "indica.lex"
{ put_indic(CON_DDH); }
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 688 "indica.lex"
{ put_indic(CON_NN); }
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 690 "indica.lex"
{ put_indic(CON_T); }
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 692 "indica.lex"
{ put_indic(CON_TH); }
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 694 "indica.lex"
{ put_indic(CON_D); }
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 696 "indica.lex"
{ put_indic(CON_DH); }
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 698 "indica.lex"
{ put_indic(CON_N); }
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 700 "indica.lex"
{ put_indic(CON_NNN); }
	YY_BREAK
case 210:
YY_RULE_SETUP
#line 702 "indica.lex"
{ put_indic(CON_P); }
	YY_BREAK
case 211:
YY_RULE_SETUP
#line 704 "indica.lex"
{ put_indic(CON_PH); }
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 706 "indica.lex"
{ put_indic(CON_B); }
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 708 "indica.lex"
{ put_indic(CON_BH); }
	YY_BREAK
case 214:
YY_RULE_SETUP
#line 710 "indica.lex"
{ put_indic(CON_M); }
	YY_BREAK
case 215:
YY_RULE_SETUP
#line 712 "indica.lex"
{ put_indic(CON_Y); }
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 714 "indica.lex"
{ put_indic(CON_R); }
	YY_BREAK
case 217:
YY_RULE_SETUP
#line 716 "indica.lex"
{ put_indic(CON_RR); }
	YY_BREAK
case 218:
YY_RULE_SETUP
#line 718 "indica.lex"
{ put_indic(CON_L); }
	YY_BREAK
case 219:
YY_RULE_SETUP
#line 720 "indica.lex"
{ put_indic(CON_LL); }
	YY_BREAK
case 220:
YY_RULE_SETUP
#line 722 "indica.lex"
{ put_indic(CON_LLL); }
	YY_BREAK
case 221:
YY_RULE_SETUP
#line 724 "indica.lex"
{ put_indic(CON_V); }
	YY_BREAK
case 222:
YY_RULE_SETUP
#line 726 "indica.lex"
{ put_indic(CON_SH); }
	YY_BREAK
case 223:
YY_RULE_SETUP
#line 728 "indica.lex"
{ put_indic(CON_SS); }
	YY_BREAK
case 224:
YY_RULE_SETUP
#line 730 "indica.lex"
{ put_indic(CON_S); }
	YY_BREAK
case 225:
YY_RULE_SETUP
#line 732 "indica.lex"
{ put_indic(CON_H); }
	YY_BREAK
case 226:
YY_RULE_SETUP
#line 734 "indica.lex"
{ put_indic(AVAGRAHA); }
	YY_BREAK
case 227:
YY_RULE_SETUP
#line 736 "indica.lex"
{ put_indic(VIRAMA); }
	YY_BREAK
case 228:
YY_RULE_SETUP
#line 738 "indica.lex"
{ put_indic(OM); }
	YY_BREAK
case 229:
YY_RULE_SETUP
#line 740 "indica.lex"
{ put_indic(CON_Q); }
	YY_BREAK
case 230:
YY_RULE_SETUP
#line 742 "indica.lex"
{ put_indic(CON_KKH); }
	YY_BREAK
case 231:
YY_RULE_SETUP
#line 744 "indica.lex"
{ put_indic(CON_GHH); }
	YY_BREAK
case 232:
YY_RULE_SETUP
#line 746 "indica.lex"
{ put_indic(CON_DDDH); }
	YY_BREAK
case 233:
YY_RULE_SETUP
#line 748 "indica.lex"
{ put_indic(CON_RH); }
	YY_BREAK
case 234:
YY_RULE_SETUP
#line 750 "indica.lex"
{ put_indic(CON_F); }
	YY_BREAK
case 235:
YY_RULE_SETUP
#line 752 "indica.lex"
{ put_indic(CON_YY); }
	YY_BREAK
case 236:
YY_RULE_SETUP
#line 754 "indica.lex"
{ put_indic(VBAR); }
	YY_BREAK
case 237:
YY_RULE_SETUP
#line 756 "indica.lex"
{ put_indic(VBARVBAR); }
	YY_BREAK
case 238:
YY_RULE_SETUP
#line 758 "indica.lex"
{ put_indic(CON_NAS_G); }
	YY_BREAK
case 239:
YY_RULE_SETUP
#line 760 "indica.lex"
{ put_indic(CON_NAS_C); }
	YY_BREAK
case 240:
YY_RULE_SETUP
#line 762 "indica.lex"
{ put_indic(CON_NAS_DD); }
	YY_BREAK
case 241:
YY_RULE_SETUP
#line 764 "indica.lex"
{ put_indic(CON_NAS_D); }
	YY_BREAK
case 242:
YY_RULE_SETUP
#line 766 "indica.lex"
{ put_indic(CON_NAS_B); }
	YY_BREAK
case 243:
YY_RULE_SETUP
#line 768 "indica.lex"
{ put_indic(CON_NAS_J); }
	YY_BREAK
case 244:
YY_RULE_SETUP
#line 770 "indica.lex"
{ put_indic(CON_KS); }
	YY_BREAK
case 245:
YY_RULE_SETUP
#line 772 "indica.lex"
{ put_other(yytext[0]); }
	YY_BREAK
case 246:
YY_RULE_SETUP
#line 774 "indica.lex"
{ printf("%c",yytext[2]); }
	YY_BREAK
case 247:
YY_RULE_SETUP
#line 776 "indica.lex"
{ sh_cons_vow(ANUSVARA,0,0); }
	YY_BREAK
case 248:
YY_RULE_SETUP
#line 778 "indica.lex"
{ sh_cons_vow(VISARGA,0,0); }
	YY_BREAK
case 249:
YY_RULE_SETUP
#line 780 "indica.lex"
{ if(current_input_mode!=SAMANALA) sh_lig_vow(yytext[2],yytext[5],CON_R+CON_Y,yytext[14]); else REJECT; }
	YY_BREAK
case 250:
YY_RULE_SETUP
#line 782 "indica.lex"
{ if(current_input_mode!=SAMANALA) sh_lig_vow(yytext[2],yytext[5],CON_R+CON_Y,0); else REJECT; }
	YY_BREAK
case 251:
YY_RULE_SETUP
#line 784 "indica.lex"
{ if(current_input_mode!=SAMANALA) sh_lig_vow(yytext[2],yytext[5],CON_R,yytext[11]); else REJECT; }
	YY_BREAK
case 252:
YY_RULE_SETUP
#line 786 "indica.lex"
{ if(current_input_mode!=SAMANALA) sh_lig_vow(yytext[2],yytext[5],CON_R,0); else REJECT; }
	YY_BREAK
case 253:
YY_RULE_SETUP
#line 788 "indica.lex"
{ if(current_input_mode!=SAMANALA) sh_lig_vow(yytext[2],yytext[5],CON_Y,yytext[11]); else REJECT; }
	YY_BREAK
case 254:
YY_RULE_SETUP
#line 790 "indica.lex"
{ if(current_input_mode!=SAMANALA) sh_lig_vow(yytext[2],yytext[5],CON_Y,0); else REJECT; }
	YY_BREAK
case 255:
YY_RULE_SETUP
#line 792 "indica.lex"
{ if(current_input_mode!=SAMANALA) sh_lig_vow(yytext[2],yytext[5],0,yytext[8]); else REJECT; }
	YY_BREAK
case 256:
YY_RULE_SETUP
#line 794 "indica.lex"
{ if(current_input_mode!=SAMANALA) sh_lig_vow(yytext[2],yytext[5],0,0); else REJECT; }
	YY_BREAK
case 257:
YY_RULE_SETUP
#line 796 "indica.lex"
{ if(current_input_mode==SAMANALA) sh_lig_vow(yytext[5],yytext[8],CON_R+CON_Y,yytext[17]); else REJECT; }
	YY_BREAK
case 258:
YY_RULE_SETUP
#line 798 "indica.lex"
{ if(current_input_mode==SAMANALA) sh_lig_vow(yytext[5],yytext[8],CON_R+CON_Y,0); else REJECT; }
	YY_BREAK
case 259:
YY_RULE_SETUP
#line 800 "indica.lex"
{ if(current_input_mode==SAMANALA) sh_lig_vow(yytext[5],yytext[8],CON_R,yytext[14]); else REJECT; }
	YY_BREAK
case 260:
YY_RULE_SETUP
#line 802 "indica.lex"
{ if(current_input_mode==SAMANALA) sh_lig_vow(yytext[5],yytext[8],CON_R,0); else REJECT; }
	YY_BREAK
case 261:
YY_RULE_SETUP
#line 804 "indica.lex"
{ if(current_input_mode==SAMANALA) sh_lig_vow(yytext[5],yytext[8],CON_Y,yytext[14]); else REJECT; }
	YY_BREAK
case 262:
YY_RULE_SETUP
#line 806 "indica.lex"
{ if(current_input_mode==SAMANALA) sh_lig_vow(yytext[5],yytext[8],CON_Y,0); else REJECT; }
	YY_BREAK
case 263:
YY_RULE_SETUP
#line 808 "indica.lex"
{ if(current_input_mode==SAMANALA) sh_lig_vow(yytext[5],yytext[8],0,yytext[11]); else REJECT; }
	YY_BREAK
case 264:
YY_RULE_SETUP
#line 810 "indica.lex"
{ if(current_input_mode==SAMANALA) sh_lig_vow(yytext[5],yytext[8],0,0); else REJECT; }
	YY_BREAK
case 265:
YY_RULE_SETUP
#line 812 "indica.lex"
{ sh_cons_vow(yytext[2],CON_R+CON_Y,yytext[11]); }
	YY_BREAK
case 266:
YY_RULE_SETUP
#line 814 "indica.lex"
{ sh_cons_vow(yytext[2],CON_R+CON_Y,0); }
	YY_BREAK
case 267:
YY_RULE_SETUP
#line 816 "indica.lex"
{ sh_cons_vow(yytext[2],CON_R,yytext[8]); }
	YY_BREAK
case 268:
YY_RULE_SETUP
#line 818 "indica.lex"
{ sh_cons_vow(yytext[2],CON_R,0); }
	YY_BREAK
case 269:
YY_RULE_SETUP
#line 820 "indica.lex"
{ sh_cons_vow(yytext[2],CON_Y,yytext[8]); }
	YY_BREAK
case 270:
YY_RULE_SETUP
#line 822 "indica.lex"
{ sh_cons_vow(yytext[2],CON_Y,0); }
	YY_BREAK
case 271:
YY_RULE_SETUP
#line 824 "indica.lex"
{ if(current_input_mode!=SAMANALA) sh_ra_lig_a(yytext[5],yytext[8]); else REJECT; }
	YY_BREAK
case 272:
YY_RULE_SETUP
#line 826 "indica.lex"
{ if(current_input_mode!=SAMANALA) sh_ra_cons_a(yytext[5]); else REJECT; }
	YY_BREAK
case 273:
YY_RULE_SETUP
#line 828 "indica.lex"
{ if(current_input_mode==SAMANALA) sh_ra_lig_a(yytext[11],yytext[14]); else REJECT; }
	YY_BREAK
case 274:
YY_RULE_SETUP
#line 830 "indica.lex"
{ if(current_input_mode==SAMANALA) sh_ra_cons_a(yytext[8]); else REJECT; }
	YY_BREAK
case 275:
YY_RULE_SETUP
#line 832 "indica.lex"
{ sh_cons_vow(yytext[2], 0,yytext[5]); }
	YY_BREAK
case 276:
YY_RULE_SETUP
#line 834 "indica.lex"
{ sh_cons_vow(yytext[2], 0,0); }
	YY_BREAK
case 277:
YY_RULE_SETUP
#line 836 "indica.lex"
{ sh_cons_vow(0, 0,yytext[2]); }
	YY_BREAK
case 278:
YY_RULE_SETUP
#line 838 "indica.lex"
{ fprintf(stderr,"line %d: Unrecognized Sinhala character\n",current_line); }
	YY_BREAK
case 279:
YY_RULE_SETUP
#line 840 "indica.lex"
ECHO;
	YY_BREAK
#line 3014 "lex.yy.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(SEVENBIT):
			case YY_STATE_EOF(LATEX):
			case YY_STATE_EOF(SAMANALA):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yy_hold_char;

		if ( yy_current_buffer->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between yy_current_buffer and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yy_n_chars = yy_current_buffer->yy_n_chars;
			yy_current_buffer->yy_input_file = yyin;
			yy_current_buffer->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yy_c_buf_p <= &yy_current_buffer->yy_ch_buf[yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yy_c_buf_p = yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state();

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer() )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yy_did_buffer_switch_on_eof = 0;

				if ( yywrap() )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yy_c_buf_p = yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yy_c_buf_p =
					yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state();

				yy_cp = yy_c_buf_p;
				yy_bp = yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yy_c_buf_p =
				&yy_current_buffer->yy_ch_buf[yy_n_chars];

				yy_current_state = yy_get_previous_state();

				yy_cp = yy_c_buf_p;
				yy_bp = yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of yylex */


/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */

static int yy_get_next_buffer()
	{
	register char *dest = yy_current_buffer->yy_ch_buf;
	register char *source = yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yy_c_buf_p > &yy_current_buffer->yy_ch_buf[yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( yy_current_buffer->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yy_c_buf_p - yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a singled characater, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yy_c_buf_p - yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( yy_current_buffer->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		yy_n_chars = 0;

	else
		{
		int num_to_read =
			yy_current_buffer->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */
#ifdef YY_USES_REJECT
			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );
#else

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = yy_current_buffer;

			int yy_c_buf_p_offset =
				(int) (yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yy_flex_realloc( (void *) b->yy_ch_buf,
							 b->yy_buf_size + 2 );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = yy_current_buffer->yy_buf_size -
						number_to_move - 1;
#endif
			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&yy_current_buffer->yy_ch_buf[number_to_move]),
			yy_n_chars, num_to_read );
		}

	if ( yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			yy_current_buffer->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	yy_n_chars += number_to_move;
	yy_current_buffer->yy_ch_buf[yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	yy_current_buffer->yy_ch_buf[yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yytext_ptr = &yy_current_buffer->yy_ch_buf[0];

	return ret_val;
	}


/* yy_get_previous_state - get the state just before the EOB char was reached */

static yy_state_type yy_get_previous_state()
	{
	register yy_state_type yy_current_state;
	register char *yy_cp;

	yy_current_state = yy_start;
	yy_current_state += YY_AT_BOL();
	yy_state_ptr = yy_state_buf;
	*yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yytext_ptr + YY_MORE_ADJ; yy_cp < yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 8);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 718 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
	}


/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */

#ifdef YY_USE_PROTOS
static yy_state_type yy_try_NUL_trans( yy_state_type yy_current_state )
#else
static yy_state_type yy_try_NUL_trans( yy_current_state )
yy_state_type yy_current_state;
#endif
	{
	register int yy_is_jam;

	register YY_CHAR yy_c = 8;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 718 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	*yy_state_ptr++ = yy_current_state;
	yy_is_jam = (yy_current_state == 717);

	return yy_is_jam ? 0 : yy_current_state;
	}


#ifndef YY_NO_UNPUT
#ifdef YY_USE_PROTOS
static void yyunput( int c, register char *yy_bp )
#else
static void yyunput( c, yy_bp )
int c;
register char *yy_bp;
#endif
	{
	register char *yy_cp = yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yy_hold_char;

	if ( yy_cp < yy_current_buffer->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = yy_n_chars + 2;
		register char *dest = &yy_current_buffer->yy_ch_buf[
					yy_current_buffer->yy_buf_size + 2];
		register char *source =
				&yy_current_buffer->yy_ch_buf[number_to_move];

		while ( source > yy_current_buffer->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		yy_n_chars = yy_current_buffer->yy_buf_size;

		if ( yy_cp < yy_current_buffer->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;


	yytext_ptr = yy_bp;
	yy_hold_char = *yy_cp;
	yy_c_buf_p = yy_cp;
	}
#endif	/* ifndef YY_NO_UNPUT */


#ifdef __cplusplus
static int yyinput()
#else
static int input()
#endif
	{
	int c;

	*yy_c_buf_p = yy_hold_char;

	if ( *yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yy_c_buf_p < &yy_current_buffer->yy_ch_buf[yy_n_chars] )
			/* This was really a NUL. */
			*yy_c_buf_p = '\0';

		else
			{ /* need more input */
			yytext_ptr = yy_c_buf_p;
			++yy_c_buf_p;

			switch ( yy_get_next_buffer() )
				{
				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap() )
						{
						yy_c_buf_p =
						yytext_ptr + YY_MORE_ADJ;
						return EOF;
						}

					if ( ! yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yy_c_buf_p = yytext_ptr + YY_MORE_ADJ;
					break;

				case EOB_ACT_LAST_MATCH:
#ifdef __cplusplus
					YY_FATAL_ERROR(
					"unexpected last match in yyinput()" );
#else
					YY_FATAL_ERROR(
					"unexpected last match in input()" );
#endif
				}
			}
		}

	c = *(unsigned char *) yy_c_buf_p;	/* cast for 8-bit char's */
	*yy_c_buf_p = '\0';	/* preserve yytext */
	yy_hold_char = *++yy_c_buf_p;

	yy_current_buffer->yy_at_bol = (c == '\n');

	return c;
	}


#ifdef YY_USE_PROTOS
void yyrestart( FILE *input_file )
#else
void yyrestart( input_file )
FILE *input_file;
#endif
	{
	if ( ! yy_current_buffer )
		yy_current_buffer = yy_create_buffer( yyin, YY_BUF_SIZE );

	yy_init_buffer( yy_current_buffer, input_file );
	yy_load_buffer_state();
	}


#ifdef YY_USE_PROTOS
void yy_switch_to_buffer( YY_BUFFER_STATE new_buffer )
#else
void yy_switch_to_buffer( new_buffer )
YY_BUFFER_STATE new_buffer;
#endif
	{
	if ( yy_current_buffer == new_buffer )
		return;

	if ( yy_current_buffer )
		{
		/* Flush out information for old buffer. */
		*yy_c_buf_p = yy_hold_char;
		yy_current_buffer->yy_buf_pos = yy_c_buf_p;
		yy_current_buffer->yy_n_chars = yy_n_chars;
		}

	yy_current_buffer = new_buffer;
	yy_load_buffer_state();

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yy_did_buffer_switch_on_eof = 1;
	}


#ifdef YY_USE_PROTOS
void yy_load_buffer_state( void )
#else
void yy_load_buffer_state()
#endif
	{
	yy_n_chars = yy_current_buffer->yy_n_chars;
	yytext_ptr = yy_c_buf_p = yy_current_buffer->yy_buf_pos;
	yyin = yy_current_buffer->yy_input_file;
	yy_hold_char = *yy_c_buf_p;
	}


#ifdef YY_USE_PROTOS
YY_BUFFER_STATE yy_create_buffer( FILE *file, int size )
#else
YY_BUFFER_STATE yy_create_buffer( file, size )
FILE *file;
int size;
#endif
	{
	YY_BUFFER_STATE b;

	b = (YY_BUFFER_STATE) yy_flex_alloc( sizeof( struct yy_buffer_state ) );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yy_flex_alloc( b->yy_buf_size + 2 );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
	}


#ifdef YY_USE_PROTOS
void yy_delete_buffer( YY_BUFFER_STATE b )
#else
void yy_delete_buffer( b )
YY_BUFFER_STATE b;
#endif
	{
	if ( ! b )
		return;

	if ( b == yy_current_buffer )
		yy_current_buffer = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yy_flex_free( (void *) b->yy_ch_buf );

	yy_flex_free( (void *) b );
	}


#ifndef YY_ALWAYS_INTERACTIVE
#ifndef YY_NEVER_INTERACTIVE
extern int isatty YY_PROTO(( int ));
#endif
#endif

#ifdef YY_USE_PROTOS
void yy_init_buffer( YY_BUFFER_STATE b, FILE *file )
#else
void yy_init_buffer( b, file )
YY_BUFFER_STATE b;
FILE *file;
#endif


	{
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

#if YY_ALWAYS_INTERACTIVE
	b->yy_is_interactive = 1;
#else
#if YY_NEVER_INTERACTIVE
	b->yy_is_interactive = 0;
#else
	b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
#endif
#endif
	}


#ifdef YY_USE_PROTOS
void yy_flush_buffer( YY_BUFFER_STATE b )
#else
void yy_flush_buffer( b )
YY_BUFFER_STATE b;
#endif

	{
	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == yy_current_buffer )
		yy_load_buffer_state();
	}


#ifndef YY_NO_SCAN_BUFFER
#ifdef YY_USE_PROTOS
YY_BUFFER_STATE yy_scan_buffer( char *base, yy_size_t size )
#else
YY_BUFFER_STATE yy_scan_buffer( base, size )
char *base;
yy_size_t size;
#endif
	{
	YY_BUFFER_STATE b;

	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yy_flex_alloc( sizeof( struct yy_buffer_state ) );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b );

	return b;
	}
#endif


#ifndef YY_NO_SCAN_STRING
#ifdef YY_USE_PROTOS
YY_BUFFER_STATE yy_scan_string( yyconst char *str )
#else
YY_BUFFER_STATE yy_scan_string( str )
yyconst char *str;
#endif
	{
	int len;
	for ( len = 0; str[len]; ++len )
		;

	return yy_scan_bytes( str, len );
	}
#endif


#ifndef YY_NO_SCAN_BYTES
#ifdef YY_USE_PROTOS
YY_BUFFER_STATE yy_scan_bytes( yyconst char *bytes, int len )
#else
YY_BUFFER_STATE yy_scan_bytes( bytes, len )
yyconst char *bytes;
int len;
#endif
	{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;

	/* Get memory for full buffer, including space for trailing EOB's. */
	n = len + 2;
	buf = (char *) yy_flex_alloc( n );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < len; ++i )
		buf[i] = bytes[i];

	buf[len] = buf[len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
	}
#endif


#ifndef YY_NO_PUSH_STATE
#ifdef YY_USE_PROTOS
static void yy_push_state( int new_state )
#else
static void yy_push_state( new_state )
int new_state;
#endif
	{
	if ( yy_start_stack_ptr >= yy_start_stack_depth )
		{
		yy_size_t new_size;

		yy_start_stack_depth += YY_START_STACK_INCR;
		new_size = yy_start_stack_depth * sizeof( int );

		if ( ! yy_start_stack )
			yy_start_stack = (int *) yy_flex_alloc( new_size );

		else
			yy_start_stack = (int *) yy_flex_realloc(
					(void *) yy_start_stack, new_size );

		if ( ! yy_start_stack )
			YY_FATAL_ERROR(
			"out of memory expanding start-condition stack" );
		}

	yy_start_stack[yy_start_stack_ptr++] = YY_START;

	BEGIN(new_state);
	}
#endif


#ifndef YY_NO_POP_STATE
static void yy_pop_state()
	{
	if ( --yy_start_stack_ptr < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN(yy_start_stack[yy_start_stack_ptr]);
	}
#endif


#ifndef YY_NO_TOP_STATE
static int yy_top_state()
	{
	return yy_start_stack[yy_start_stack_ptr - 1];
	}
#endif

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

#ifdef YY_USE_PROTOS
static void yy_fatal_error( yyconst char msg[] )
#else
static void yy_fatal_error( msg )
char msg[];
#endif
	{
	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
	}



/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
		yytext[yyleng] = yy_hold_char; \
		yy_c_buf_p = yytext + n - YY_MORE_ADJ; \
		yy_hold_char = *yy_c_buf_p; \
		*yy_c_buf_p = '\0'; \
		yyleng = n; \
		} \
	while ( 0 )


/* Internal utility routines. */

#ifndef yytext_ptr
#ifdef YY_USE_PROTOS
static void yy_flex_strncpy( char *s1, yyconst char *s2, int n )
#else
static void yy_flex_strncpy( s1, s2, n )
char *s1;
yyconst char *s2;
int n;
#endif
	{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
	}
#endif


#ifdef YY_USE_PROTOS
static void *yy_flex_alloc( yy_size_t size )
#else
static void *yy_flex_alloc( size )
yy_size_t size;
#endif
	{
	return (void *) malloc( size );
	}

#ifdef YY_USE_PROTOS
static void *yy_flex_realloc( void *ptr, yy_size_t size )
#else
static void *yy_flex_realloc( ptr, size )
void *ptr;
yy_size_t size;
#endif
	{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
	}

#ifdef YY_USE_PROTOS
static void yy_flex_free( void *ptr )
#else
static void yy_flex_free( ptr )
void *ptr;
#endif
	{
	free( ptr );
	}

#if YY_MAIN
int main()
	{
	yylex();
	return 0;
	}
#endif
#line 840 "indica.lex"


void sh_place_normal_vowel(char *s, int extension, int vow)
{
	char r[32],y[32];
	
	switch (extension) {
		case 0x00: r[0] = 0x00; y[0] = 0x00; break;
		case CON_R:	strcpy(r,"r"); y[0] = 0x00; break;
		case CON_Y:	r[0] = 0x00; strcpy(y,"a\\SHb\\char205"); break;
		case CON_R + CON_Y: strcpy(r,"r"); strcpy(y,"a\\SHb\\char205"); break;
		default: break; }

	switch (vow) {
		case 0:	printf("%s%s%s",s,r,y); break;
		case VOW_A: printf("%s%sa%s",s,y,r); break;
		case VOW_AA: printf("%s%sa%s\\char0",s,y,r); break;
		case VOW_AAA: if ((!strcmp(s,"\\char29")) && (extension == 0x00)) printf("\\char29u"); else
						printf("%s%sa%s\\char8",s,y,r); break;
		case VOW_AAAA: if ((!strcmp(s,"\\char29")) && (extension == 0x00)) printf("\\char29uu"); else
						printf("%s%sa%s\\char9",s,y,r); break;
		case VOW_I: printf("%s%si%s",s,y,r); break;
		case VOW_II: printf("%s%sii%s",s,y,r); break;
		case VOW_U: if ((extension == 0x00) || (extension == CON_Y)) 
			{	if ((!strcmp(s,"\\char29")) && (extension == 0x00)) printf("\\char29a\\char8"); else
				printf("%s%su",s,y); }
			else if ((extension == CON_R) || (extension == CON_R+CON_Y)) printf("%s%sa\\char1",s,y); break;
		case VOW_UU: if ((extension == 0x00) || (extension == CON_Y)) 
			{	if ((!strcmp(s,"\\char29")) && (extension == 0x00)) printf("\\char29a\\char9"); else
				printf("%s%suu",s,y); }
			else if ((extension == CON_R) || (extension == CON_R+CON_Y)) printf("%s%sa\\char2",s,y); break;
		case VOW_R: printf("%s%sa%s\\char1",s,y,r); break;
		case VOW_RR: printf("%s%sa%s\\char2",s,y,r); break;
		case VOW_L: printf("%s%sa%s\\char3",s,y,r); break;
		case VOW_LL: printf("%s%sa%s\\char4",s,y,r); break;
		case CANDRA_E: break;
		case VOW_E: printf("\\char5%s%sa%s",s,y,r); break;
		case VOW_EE: printf("\\char5%s%s%s",s,y,r); break;
		case VOW_AI: printf("\\char6%s%sa%s",s,y,r); break;
		case CANDRA_O: break;
		case VOW_O: printf("\\char5%s%sa%s\\char0",s,y,r); break;
		case VOW_OO: printf("\\char5%s%sa%s\\char7",s,y,r); break;
		case VOW_AU: printf("\\char5%s%sa%s\\char3",s,y,r); break;
		default: break;
		}
}

void sh_place_da_like_vowel(char *s, int extension, int vow)
{
	char r[32],y[32];
	
	switch (extension) {
		case 0x00:	r[0] = 0x00; y[0] = 0x00; break;
		case CON_R: strcpy(r,"r"); y[0] = 0x00; break;
		case CON_Y: r[0] = 0x00; strcpy(y,"a\\SHb\\char'205"); break;
		case CON_R + CON_Y:	strcpy(r,"r"); strcpy(y,"a\\SHb\\char'205"); break;
		default: break; }

	switch (vow) {
		case 0:	switch(extension) {
			case CON_R: printf("%sr",s); break;
			case CON_Y: printf("%sa\\char205",s); break;
			case CON_R+CON_Y: printf("%sar\\char205",s); break;
			default: printf("%s",s); break; } break;
		case VOW_A: switch(extension) {
			case CON_R: printf("%sar",s); break;
			case CON_Y: printf("%sy",s); break;
			case CON_R+CON_Y: printf("%sar\\char200",s); break;
			default: printf("%sa",s); break; } break;
		case VOW_AA: switch(extension) {
			case CON_R: printf("%sar\\char0",s); break;
			case CON_Y: printf("%sy\\char0",s); break;
			case CON_R+CON_Y: printf("%sar\\char200\\char0",s); break;
			default: printf("%saa",s); break; } break;
		case VOW_AAA: switch(extension) {
			case CON_R: printf("%sar\\char8",s); break;
			case CON_Y: printf("%sy\\char8",s); break;
			case CON_R+CON_Y: printf("%sar\\char200\\char8",s); break;
			default: printf("%saaa",s); break; } break;
		case VOW_AAAA: switch(extension) {
			case CON_R: printf("%sar\\char9",s); break;
			case CON_Y: printf("%sy\\char9",s); break;
			case CON_R+CON_Y: printf("%sar\\char200\\char9",s); break;
			default: printf("%saaaa",s); break; } break;
		case VOW_I: switch(extension) {
			case CON_R: printf("%sir",s); break;
			case CON_Y: printf("%sa\\char205i",s); break;
			case CON_R+CON_Y: printf("%sar\\char205i",s); break;
			default: printf("%si",s); break; } break;
		case VOW_II: switch(extension) {
			case CON_R: printf("%siir",s); break;
			case CON_Y: printf("%sa\\char205ii",s); break;
			case CON_R+CON_Y: printf("%sar\\char205ii",s); break;
			default: printf("%sii",s); break; } break;
		case VOW_U: switch(extension) {
			case CON_R: printf("%srr",s); break;
			case CON_Y: printf("%sa\\char205u",s); break;
			case CON_R+CON_Y: printf("%sar\\char205u",s); break;
			default: printf("%su",s); break; } break;
		case VOW_UU: switch(extension) {
			case CON_R: printf("%srrr",s); break;
			case CON_Y: printf("%sa\\char205uu",s); break;
			case CON_R+CON_Y: printf("%sar\\char205uu",s); break;
			default: printf("%suu",s); break; } break;
		case VOW_R: switch(extension) {
			case CON_R: printf("%s\\char29a\\char1",s); break;
			case CON_Y: printf("%sy\\char1",s); break;
			case CON_R+CON_Y: printf("%s\\char29\\char16\\char1",s); break;
			default: printf("%srr",s); break; } break;
		case VOW_RR: switch(extension) {
			case CON_R: printf("%s\\char29a\\char2",s); break;
			case CON_Y: printf("%sy\\char2",s); break;
			case CON_R+CON_Y: printf("%s\\char29\\char16\\char2",s); break;
			default: printf("%srrr",s); break; } break;
		case VOW_L: switch(extension) {
			case CON_R: printf("%sar\\char3",s); break;
			case CON_Y: printf("%sy\\char3",s); break;
			case CON_R+CON_Y: printf("%sar\\char205a\\char3",s); break;
			default: printf("%sa\\char3",s); break; } break;
		case VOW_LL: switch(extension) {
			case CON_R: printf("%sar\\char4",s); break;
			case CON_Y: printf("%sy\\char4",s); break;
			case CON_R+CON_Y: printf("%sar\\char205a\\char4",s); break;
			default: printf("%sa\\char4",s); break; } break;
		case CANDRA_E: break;
		case VOW_E: switch(extension) {
			case CON_R: printf("\\char5%sar",s); break;
			case CON_Y: printf("\\char5%sy",s); break;
			case CON_R+CON_Y: printf("\\char5%sar\\char205a",s); break;
			default: printf("\\char5%sa",s); break; } break;
		case VOW_EE: switch(extension) {
			case CON_R: printf("\\char5%sr",s); break;
			case CON_Y: printf("\\char5%sa\\char205",s); break;
			case CON_R+CON_Y: printf("\\char5%sar\\char205",s); break;
			default: printf("\\char5%s",s); break; } break;
		case VOW_AI: switch(extension) {
			case CON_R: printf("\\char6%sar",s); break;
			case CON_Y: printf("\\char6%sy",s); break;
			case CON_R+CON_Y: printf("\\char6%sar\\char205a",s); break;
			default: printf("\\char6%sa",s); break; } break;
		case CANDRA_O: break;
		case VOW_O: switch(extension) {
			case CON_R: printf("\\char5%sar\\char0",s); break;
			case CON_Y: printf("\\char5%sy\\char0",s); break;
			case CON_R+CON_Y: printf("\\char5%sar\\char205a\\char0",s); break;
			default: printf("\\char5%saa",s); break; } break;
		case VOW_OO: switch(extension) {
			case CON_R: printf("\\char5%sar\\char7",s); break;
			case CON_Y: printf("\\char5%sy\\char7",s); break;
			case CON_R+CON_Y: printf("\\char5%sar\\char205a\\char7",s); break;
			default: printf("\\char5%so",s); break; } break;
		case VOW_AU: switch(extension) {
			case CON_R: printf("\\char5%sar\\char3",s); break;
			case CON_Y: printf("\\char5%sy\\char3",s); break;
			case CON_R+CON_Y: printf("\\char5%sar\\char205a\\char3",s); break;
			default: printf("\\char5%sa\\char3",s); break; } break;
		default: break;}
}

void sh_cons_vow(int con, int extension, int vow)
{
	printf("{");
	if (con == 0) {
		switch (vow) {
			case VOW_A:		printf("\\SHa\\char16"); break;
			case VOW_AA:	printf("\\SHa\\char16\\char0"); break;
			case VOW_AAA:	printf("\\SHa\\char16\\char8"); break;
			case VOW_AAAA:	printf("\\SHa\\char16\\char9"); break;
			case VOW_I:		printf("\\SHa\\char17"); break;
			case VOW_II:	printf("\\SHa\\char18"); break;
			case VOW_U:		printf("\\SHa\\char19"); break;
			case VOW_UU:	printf("\\SHa\\char19\\char3"); break;
			case VOW_R:		printf("\\SHa\\char20\\char1"); break;
			case VOW_RR:	printf("\\SHa\\char20\\char2"); break;
			case VOW_L:		printf("\\SHa\\char21"); break;
			case VOW_LL:	printf("\\SHa\\char21\\char3"); break;
			case CANDRA_E:	break;
			case VOW_E:		printf("\\SHa\\char22"); break;
			case VOW_EE:	printf("\\SHa\\char23"); break;
			case VOW_AI:	printf("\\SHa\\char5\\char22"); break;
			case CANDRA_O:	break;
			case VOW_O:		printf("\\SHa\\char24"); break;
			case VOW_OO:	printf("\\SHa\\char25"); break;
			case VOW_AU:	printf("\\SHa\\char24\\char3"); break;
			default: break;
			}}
	else if (con == ANUSVARA) printf("\\SHa\\char11");
	else if (con == VISARGA) printf("\\SHa\\char10");
	else {
		if ((con >= 30) && (con <= 55) && (con != 39) && (con != 47)) printf("\\SHa");
		else printf("\\SHb");
		if (sh_hyphens_activated == TRUE) printf("\\-"); else sh_hyphens_activated = TRUE;
		if (r_con_a == TRUE) printf("{}r");
		switch(con) {
			case CON_K: 	sh_place_normal_vowel("\\char77",extension,vow); break;
			case CON_KH: 	sh_place_normal_vowel("\\char85",extension,vow); break;
			case CON_G: 	sh_place_normal_vowel("\\char66",extension,vow); break;
			case CON_GH: 	sh_place_normal_vowel("\\char101",extension,vow); break;
			case CON_NG: 	sh_place_normal_vowel("\\char109",extension,vow); break;
			case CON_C: 	sh_place_normal_vowel("\\char117",extension,vow); break;
			case CON_CH: 	sh_place_normal_vowel("\\char125",extension,vow); break;
			case CON_J: 	sh_place_normal_vowel("\\char133",extension,vow); break;
			case CON_JH: 	sh_place_normal_vowel("\\char141",extension,vow); break;
			case CON_NY: 	if(current_input_mode == SAMANALA)
					{
						sh_place_normal_vowel("\\char139",extension,vow); break;
					}
					else
					{
						sh_place_da_like_vowel("\\char139",extension,vow); break;
					}
			case CON_TT: 	sh_place_normal_vowel("\\char149",extension,vow); break;
			case CON_TTH: 	sh_place_normal_vowel("\\char157",extension,vow); break;
			case CON_DD: 	sh_place_normal_vowel("\\char165",extension,vow); break;
			case CON_DDH: 	sh_place_normal_vowel("\\char173",extension,vow); break;
			case CON_NN: 	sh_place_normal_vowel("\\char181",extension,vow); break;
			case CON_T: 	sh_place_normal_vowel("\\char189",extension,vow); break;
			case CON_TH: 	sh_place_normal_vowel("\\char197",extension,vow); break;
			case CON_D: 	if(current_input_mode == SAMANALA)
					{
						sh_place_normal_vowel("\\char163",extension,vow); break;
					}
					else
					{
						sh_place_da_like_vowel("\\char163",extension,vow); break;
					}
			case CON_DH: 	sh_place_normal_vowel("\\char205",extension,vow); break;
			case CON_N: 	sh_place_normal_vowel("\\char213",extension,vow); break;
			case CON_NNN: 	break;
			case CON_P: 	sh_place_normal_vowel("\\char221",extension,vow); break;
			case CON_PH: 	sh_place_normal_vowel("\\char229",extension,vow); break;
			case CON_B: 	sh_place_normal_vowel("\\char237",extension,vow); break;
			case CON_BH: 	sh_place_normal_vowel("\\char245",extension,vow); break;
			case CON_M: 	sh_place_normal_vowel("\\char253",extension,vow); break;
			case CON_Y: 	sh_place_normal_vowel("\\char21",extension,vow); break;
			case CON_R: 	sh_place_normal_vowel("\\char29",extension,vow); break;
			case CON_RR: 	break;
			case CON_L: 	sh_place_normal_vowel("\\char37",extension,vow); break;
			case CON_LL: 	sh_place_normal_vowel("\\char85",extension,vow); break;
			case CON_V: 	sh_place_normal_vowel("\\char14",extension,vow); break;
			case CON_SH: 	sh_place_normal_vowel("\\char53",extension,vow); break;
			case CON_SS: 	sh_place_normal_vowel("\\char61",extension,vow); break;
			case CON_S: 	sh_place_normal_vowel("\\char69",extension,vow); break;
			case CON_H: 	sh_place_normal_vowel("\\char77",extension,vow); break;
			case CON_F: 	sh_place_normal_vowel("\\char213",extension,vow); break;
			case CON_NAS_G: 	sh_place_normal_vowel("\\char93",extension,vow); break;
			case CON_NAS_C: 	sh_place_normal_vowel("\\char101",extension,vow); break;
			case CON_NAS_DD: 	sh_place_normal_vowel("\\char109",extension,vow); break;
			case CON_NAS_D: 	if(current_input_mode == SAMANALA)
						{
							sh_place_normal_vowel("\\char187",extension,vow); break;
						}
						else
						{
					 		sh_place_da_like_vowel("\\char187",extension,vow); break;
						}
			case CON_NAS_B: 	sh_place_normal_vowel("\\char117",extension,vow); break;
			case CON_NAS_J: 	sh_place_normal_vowel("\\char125",extension,vow); break;
			case CON_KS: 		break;
			case CON_LLL: 		break;
			default: break;
			}
		}
	printf("}");
}

void sh_ra_cons_a(int con)
{
	r_con_a = TRUE; sh_cons_vow(con, 0, 0); r_con_a = FALSE; 
}

void sh_lig_vow(int cona, int conb, int extension, int vow)
{
	if ((cona == CON_D) && (conb == CON_V)) printf("{\\SHb");
	else printf("{\\SHc");
	if (sh_hyphens_activated == TRUE) printf("\\-"); else sh_hyphens_activated = TRUE;
	if (r_con_a == TRUE) printf("{}r");
	switch(cona) {
		case CON_K: switch(conb) {
			case CON_V: sh_place_normal_vowel("\\char15",extension,vow); break;
			case CON_SS: sh_place_normal_vowel("\\char61",extension,vow); break;
			default: break; } break;
		case CON_N: switch(conb) {
			case CON_DH: sh_place_normal_vowel("\\char69",extension,vow); break;
			case CON_TH: sh_place_normal_vowel("\\char77",extension,vow); break;
			case CON_D: 	if(current_input_mode == SAMANALA)
					{
						sh_place_normal_vowel("\\char91",extension,vow); break;
					}
					else
					{
						sh_place_da_like_vowel("\\char91",extension,vow); break;
					}
			default: break; } break;
		case CON_J: switch(conb) {
			case CON_NY: 	if(current_input_mode == SAMANALA)
					{
						sh_place_normal_vowel("\\char27",extension,vow); break;
					}
					else
					{
						sh_place_da_like_vowel("\\char27",extension,vow); break;
					}
			default: break; } break;
		case CON_T: switch(conb) {
			case CON_TH: sh_place_normal_vowel("\\char109",extension,vow); break;
			default: break; } break;
		case CON_D: switch(conb) {
			case CON_V: sh_place_normal_vowel("\\char101",extension,vow); break;
			default: break; } break;
		default: break; }
		printf("}");
}

void sh_ra_lig_a(int cona, int conb)
{
	r_con_a = TRUE; sh_lig_vow(cona, conb, 0, 0); r_con_a = FALSE; 
}

void put_indic(int code)
{
unsigned char s[4];

s[0] = 0x01;
s[1] = current_language;
s[2] = code;
s[3] = 0x00;

if (strlen(buffer) > 1000) release_buffer();
strcat(buffer,s);
/* printf("Buffer is: '%s' of length %d\n",buffer,strlen(buffer)); */
}

void put_other(unsigned char xx)
{
unsigned char s[4];

s[0] = 0x01;
s[1] = 0xff;
s[2] = xx;
s[3] = 0x00;

if (strlen(buffer) > 1000) release_buffer();
strcat(buffer,s);
/* printf("Buffer is: '%s' of length %d\n",buffer,strlen(buffer)); */
}

void release_buffer(void)
{
	if ((strlen(buffer) > 0) && (strlen(buffer) < 1024)) 
		{ for (i=strlen(buffer)-1;i>=0;i--) { unput(buffer[i]); /* printf(": char %d=%d:",i,buffer[i]); */ }} 
	buffer[0] = 0x00; /* printf("step-1"); */
	sh_hyphens_activated = FALSE;
}

unsigned int hash(char *key)
{
long int number= 0L;
int k= 0;

for(k= 0;(key[k]!=0)&&(k<32);k++) number+= abs((int)key[k]);
k= ((unsigned int)(number % HASH_TABLE_SIZE));
return k;
}

void hash_insert(command_type command)
{
unsigned int hash_value= hash(command.name);
BOOLEAN already_there= FALSE;
hash_list_pointer ptr,trail= NULL,lead= hash_table[hash_value];

for(;lead;trail= lead,lead= lead->link){
	if(!strcmp(lead->command.name,command.name))
	already_there= TRUE;
	}
if(already_there==FALSE){
	ptr= (hash_list_pointer)malloc(sizeof(struct hash_list));
	if(!(ptr)){printf("\nERROR: no more memory for hashing!!...\n");
	exit(0);
	}
ptr->command= command;
ptr->link= NULL;
if(trail) trail->link= ptr;
	else hash_table[hash_value]= ptr;
if(debug==TRUE) printf("%s Just placed %s in hash_table[%d]...", DEBUG_PROMPT,command.name,hash_value);}
}

int look_in_hash(char name_[MAX_COMMAND_NAME_LENGTH])
{
unsigned int hash_value= hash(name_);
hash_list_pointer trail= NULL,lead= hash_table[hash_value];
BOOLEAN found= FALSE;

for(;((lead)&&(found==FALSE));trail= lead,lead= lead->link){
	if(!strcmp(lead->command.name,name_)) {
		found= TRUE;
		if(debug==TRUE)printf("%s Just found command %s in the hash table, it has ID %d", DEBUG_PROMPT,lead->command.name,lead->command.ID);
		return lead->command.ID;
		}
	}
if(found==FALSE) {
	if(debug==TRUE)printf("%s Couldn't find command %s in the hash table, putting it back into the stream", DEBUG_PROMPT,name_);
	return-1;
	}
}

void initialize_hash_table(void)
{
	command_type command;
	
	strcpy(command.name,"ALIAS"); command.ID = 1; hash_insert(command);

	strcpy(command.name,"UNICODE"); command.ID = 10; hash_insert(command);
	strcpy(command.name,"SEVENBIT"); command.ID = 11; hash_insert(command);
	strcpy(command.name,"CSX"); command.ID = 12; hash_insert(command);
	strcpy(command.name,"LATEX"); command.ID = 13; hash_insert(command);
	strcpy(command.name,"SAMANALA"); command.ID = 14; hash_insert(command);

	strcpy(command.name,"NIL"); command.ID = 20; hash_insert(command);
	strcpy(command.name,"HINDI"); command.ID = 21; hash_insert(command);
	strcpy(command.name,"SANSKRIT"); command.ID = 22; hash_insert(command);
	strcpy(command.name,"BENGALI"); command.ID = 23; hash_insert(command);
	strcpy(command.name,"GURMUKHI"); command.ID = 24; hash_insert(command);
	strcpy(command.name,"GUJARATI"); command.ID = 25; hash_insert(command);
	strcpy(command.name,"TAMIL"); command.ID = 26; hash_insert(command);
	strcpy(command.name,"TELUGU"); command.ID = 27; hash_insert(command);
	strcpy(command.name,"KANNADA"); command.ID = 28; hash_insert(command);
	strcpy(command.name,"MALAYALAM"); command.ID = 29; hash_insert(command);
	strcpy(command.name,"ORIYA"); command.ID = 30; hash_insert(command);
	strcpy(command.name,"SINHALESE"); command.ID = 31; hash_insert(command);
	strcpy(command.name,"SINHALA"); command.ID = 31; hash_insert(command);
	strcpy(command.name,"TIBETAN"); command.ID = 32; hash_insert(command);
}	

main(int argc, char *argv[])
{
	if( (argc==2) && (strcmp(argv[1],"-v")==0) )
	{
		fprintf(stderr, "indica version %s\n",VERSION);
		exit(0);
	}
	initialize_hash_table(); buffer[0] = 0x00;
	yylex();
	return 0;
}

yywrap()
{
	return 1;
}
